SystemOrganization addCategory: #ConfigurationOfMetacello!

Object subclass: #ConfigurationOfMetacello
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfMetacello'!

!ConfigurationOfMetacello class methodsFor: 'deprecated' stamp: 'dkh 6/12/2012 09:37:55.692'!
alternateEnsureMetacello
	"Use this method if the primary repository 'http://seaside.gemstone.com/ss/metacello' is inaccessible.
	 Secondary repository is valid for loading versions 1.0-beta.26 and later. "

	self deprecated: 'current version of #ensureMetacello automatically tries to load using alternate repository'.
	Smalltalk at: #MetacelloProject  ifAbsent: [  
		self ensureGoferVersion: 'Gofer-Core-lr.115'.
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer version repo |
			gofer := goferClass new
				url: 'http://www.squeaksource.com/metacello';
				version: 'Metacello-Core-DaleHenrichs.348';
				version: 'Metacello-MC-DaleHenrichs.332';
				yourself.
			Smalltalk at: #SystemVersion ifPresent: [:cl | | versionString  |
				versionString := cl current version.
				(versionString beginsWith: 'Squeak3')
					ifTrue: [ gofer version: 'Metacello-Platform.squeak-dkh.5']].
			gofer load.
			"now load minimal installation from alternate repository"
			version := self project latestVersion.
			repo := MCHttpRepository 
				location: 'http://www.squeaksource.com/metacello' 
				user: '' 
				password: ''.
			(version repositoryOverrides: (Array with: (repo))) load ]]! !

!ConfigurationOfMetacello class methodsFor: 'metacello release process' stamp: 'dkh 6/12/2012 09:37:55.692'!
backupToSqueakSource
	"In order for username and password to be set correctly, you must already have the metacello repository
	 set up"

	| cacheRepository version |
	cacheRepository := MCHttpRepository location: 'http://www.squeaksource.com/metacello' user: '' password: ''.
	"need to pick up existing repository with user and password set"
	cacheRepository := MCRepositoryGroup default repositories
		detect: [ :each | each = cacheRepository ]
		ifNone: [ cacheRepository ].
	version := self project latestVersion.
	version ignoreImage: true.
	(version record: 'ALL') loadDirective
		versionDirectivesDo: [ :versionDirective | 
			| p pClass |
			versionDirective spec ~~ nil
				ifTrue: [ 
					p := versionDirective spec project.
					pClass := p configuration class.	"save packages for Gofer and Metacello only"
					(pClass == (Smalltalk at: #ConfigurationOfGofer) or: [ pClass == self ])
						ifTrue: [ 
							| policy |
							policy := ((Smalltalk at: #MetacelloLoaderPolicy) new)
								cacheRepository: cacheRepository;
								ignoreImage: true;
								yourself.	"fetch Gofer or Metacello configuration"
							p fetchProject: policy.
							versionDirective
								packagesDo: [ :packageDirective | 
									"skip nested configurations"
									(packageDirective spec name beginsWith: 'ConfigurationOf')
										ifFalse: [ 
											"fetch mcz file"
											packageDirective spec fetchPackage: policy ] ] ] ] ]
					! !

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'dkh 9/14/2012 15:23'!
bootstrapMetacelloFrom: repositoryUrl
    "Corresponds to version 1.0-beta.31.1.5"

    | minimumPackages |
    self ensureGoferVersion: 'Gofer-Core-lr.115' repositoryUrl: repositoryUrl.
    minimumPackages := OrderedCollection
        withAll: #('Metacello-Base-DaleHenrichs.19' 'Metacello-Core-dkh.492' 'Metacello-MC-dkh.664').
    self platformPackage ifNotNil: [ :pkg | minimumPackages add: pkg ].
    minimumPackages do: [ :pkg | self bootstrapPackage: pkg from: repositoryUrl ]! !

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'dkh 6/12/2012 09:37:55.692'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := (MCCacheRepository default includesVersionNamed: aString)
		ifTrue: [MCCacheRepository default]
		ifFalse: [MCHttpRepository
				location: aPath
				user: ''
				password: ''].
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfMetacello class methodsFor: 'metacello release process' stamp: 'dkh 6/12/2012 09:37:55.692'!
copyConfigToRepos
	"In order for username and password to be set correctly, you must already have the MetacelloRepository
	 (on GemSource) repository set up"

	| targetRepository1 targetRepository2 gofer version |
	targetRepository1 := MCHttpRepository location: 'http://www.squeaksource.com/MetacelloRepository' user: '' password: ''.

	targetRepository2 := MCHttpRepository location: 'http://seaside.gemstone.com/ss/MetacelloRepository' user: '' password: ''.
	"need to pick up existing repository with user and password set"
	targetRepository2 := MCRepositoryGroup default repositories
		detect: [ :each | each = targetRepository2 ]
		ifNone: [ targetRepository2 ].

	gofer := (Smalltalk at: #Gofer) new
		gemsource: 'metacello';
		package: 'ConfigurationOfMetacello'.
	version := gofer resolved first version.
	(Array with: targetRepository1 with: targetRepository2) do: [:repo | repo storeVersion: version ]! !

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'dkh 6/12/2012 09:37:55.692'!
ensureCoreMetacello
    "Bootstrap Metacello and load the minimum support"

    self ensureMetacello: #('Metacello-Core')! !

!ConfigurationOfMetacello class methodsFor: 'deprecated' stamp: 'dkh 06/29/2013 09:47'!
ensureGoferVersion: goferVersion
  "load the p=file goferVersion if Gofer isn't loaded or an earlier version of Gofer is currently loaded"

  | goferVersionNumber goferRepository wc pName |
  self deprecated: 'Use #ensureGoferVersion:repositoryUrl: instead ... '.
  goferRepository := 'http://seaside.gemtalksystems.com/ss/metacello'.
  (Smalltalk at: #'Gofer' ifAbsent: [  ]) == nil
    ifTrue: [ ^ self bootstrapPackage: goferVersion from: goferRepository ].
  goferVersionNumber := (goferVersion copyAfterLast: $.) asNumber.
  wc := [ ((Smalltalk at: #'GoferPackageReference') name: 'Gofer') workingCopy ]
    on: Error
    do: [ :ex | 
      ex
        return:
          ((Smalltalk at: #'GoferPackageReference') name: 'Gofer-Core') workingCopy ].
  pName := wc ancestry ancestors first name.
  (pName copyAfterLast: $.) asNumber <= goferVersionNumber
    ifTrue: [ self bootstrapPackage: goferVersion from: goferRepository ]! !

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'dkh 6/12/2012 09:37:55.692'!
ensureGoferVersion: goferVersion repositoryUrl: repositoryUrl
	"load the p=file goferVersion if Gofer isn't loaded or an earlier version of Gofer is currently loaded"
	
	 | goferVersionNumber wc pName |
	(Smalltalk at: #Gofer ifAbsent: []) == nil
		ifTrue: [ ^self bootstrapPackage: goferVersion from: repositoryUrl ].
	goferVersionNumber := (goferVersion copyAfterLast: $.) asNumber.
	wc := [ ((Smalltalk at: #GoferPackageReference) name: 'Gofer') workingCopy ]
			on: Error
			do: [:ex | ex return: ((Smalltalk at: #GoferPackageReference) name: 'Gofer-Core') workingCopy ].
	pName := wc ancestry ancestors first name.
	(pName copyAfterLast: $.) asNumber <= goferVersionNumber
		ifTrue: [ self bootstrapPackage: goferVersion from: repositoryUrl ]
! !

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'SeanDeNigris 6/22/2012 11:38'!
ensureMetacello
    "Bootstrap Metacello and load the 'default' group"

    self ensureMetacello: #('batch')! !

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'dkh 06/29/2013 09:46'!
ensureMetacello: loadList
  "Bootstrap Metacello, retry using alternate repository, if primary repository is not accessible"

  Smalltalk
    at: #'MetacelloProject'
    ifAbsent: [ 
      | retry version error |
      retry := false.
      (Array
        with: 'http://seaside.gemtalksystems.com/ss/metacello'
        with: 'http://smalltalkhub.com/mc/dkh/metacello/main')
        do: [ :repositoryUrl | 
          [ 
          "bootstrap Metacello"
          self bootstrapMetacelloFrom: repositoryUrl.	"load latest version of Metacello"
          version := self project latestVersion.
          retry
            ifTrue: [ 
              "on retry, use #repositoryOverrides:"
              version
                repositoryOverrides:
                  (Array with: (MCHttpRepository location: repositoryUrl user: '' password: '')) ].
          version load: loadList.
          ^ self ]
            on: Error
            do: [ :ex | 
              error := ex.
              Transcript
                cr;
                show: 'failed ensureMetacello: ';
                show: ex description printString;
                show: '...retrying'.	"try again"
              retry := true.
              ex return: nil ] ].	"shouldn't get here unless the load failed ... throw an error"
      self
        error:
          'retry with alternate repository failed: ' , error description printString ]! !

!ConfigurationOfMetacello class methodsFor: 'help' stamp: 'dkh 6/12/2012 09:37:55.692'!
helpGettingStarted
	| stream |
	stream := WriteStream on: String new.
	stream
		nextPutAll: 'To get started, install Metacello and see the ''Getting Started'' section in the Metacello chapter of the Help Browser:';
		cr; tab; nextPutAll: 'HelpBrowser openOn: ((Smalltalk at: #MetacelloHelp) perform:  #asHelpTopic)';
		cr;cr;nextPutAll: 'It is also recommended that you install the Metacello Browser,. For information see';
		cr; tab; nextPutAll: 'http://metacellobrowser.dcc.uchile.cl/'.
	^ (Smalltalk at: #HelpTopic) perform: #title:contents: with: 'Getting Started' with: stream contents
! !

!ConfigurationOfMetacello class methodsFor: 'help' stamp: 'dkh 6/12/2012 09:37:55.692'!
helpInstallation
	| stream |
	stream := WriteStream on: String new.
	stream
		nextPutAll: 'To install the core functionality of Metacello, execute the following expression:';
		cr; tab; nextPutAll: 'ConfigurationOfMetacello load.';
		cr;cr;nextPutAll: 'To install the tutorial (recommended), execute the following expression:';
		cr; tab; nextPutAll: '(ConfigurationOfMetacello project version: #stable) load: #(''Tutorial'').'.
	^ (Smalltalk at: #HelpTopic) perform: #title:contents: with: 'Installing' with: stream contents
! !

!ConfigurationOfMetacello class methodsFor: 'help' stamp: 'dkh 6/12/2012 09:37:55.692'!
helpIntro
	| stream |
	stream := WriteStream on: String new.
	stream
		nextPutAll: 'Metacello is a package management system for Monticello';
		cr;cr;nextPutAll: 'Metacello Browser is written and maintained by:';
		cr;tab;nextPutAll: 'Dale Henrichs';
		cr;cr;nextPutAll: 'To submit bug reports, visit the following link:';
		cr;tab;nextPutAll: 'http://code.google.com/p/metacello/issues/entry';
		cr;cr;nextPutAll: 'For additional info see the Metacello project site:';
		cr;tab;nextPutAll: 'http://code.google.com/p/metacello/'.
	^ (Smalltalk at: #HelpTopic) perform: #title:contents: with: 'Introduction' with: stream contents! !

!ConfigurationOfMetacello class methodsFor: 'help' stamp: 'dkh 6/12/2012 09:37:55.692'!
helpPages
	| pages |
	pages := {#helpIntro. #helpInstallation. #helpGettingStarted}.
	"include MetacelloHelp if installed"
	Smalltalk at: #MetacelloHelp ifPresent: [ :cl | pages :=  pages , {cl} ].
	^ pages! !

!ConfigurationOfMetacello class methodsFor: 'metacello tool support' stamp: 'dkh 6/12/2012 09:37:55.692'!
isMetacelloConfig

	^true! !

!ConfigurationOfMetacello class methodsFor: 'metacello tool support' stamp: 'dkh 6/12/2012 09:37:55.692'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfMetacello class methodsFor: 'loading' stamp: 'SeanDeNigris 6/27/2012 14:25'!
load
	"Load a minimum installation of Metacello"

	"self load"

	^ self project latestVersion load: 'batch'.! !

!ConfigurationOfMetacello class methodsFor: 'development support' stamp: 'dkh 6/12/2012 09:37:55.692'!
loadLatestPackages
	"self loadLatestPackages"

	"Note that Metacello 1.0-beta.28 is needed and is currently unstable and in development"

	| project |
	project := self project.
	^(project latestVersion: #baseline) load: #( 'default' 'Metacello-Tutorial')! !

!ConfigurationOfMetacello class methodsFor: 'loading' stamp: 'dkh 6/12/2012 09:37:55.692'!
loadLatestVersion
	"self loadLatestVersion"

	self project updateProject.
	^self project latestVersion load! !

!ConfigurationOfMetacello class methodsFor: 'metacello tool support' stamp: 'dkh 6/12/2012 09:37:55.692'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfMetacello class methodsFor: 'deprecated' stamp: 'dkh 6/12/2012 09:37:55.692'!
oldEnsureMetacello
	"original implementation of ensureMetacello, just in case problems surface."

	self deprecated: 'use #ensureMetacello instead'.
	Smalltalk at: #MetacelloProject  ifAbsent: [  
		self ensureGoferVersion: 'Gofer-Core-lr.115'.
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				version: 'Metacello-Core-DaleHenrichs.348';
				version: 'Metacello-MC-DaleHenrichs.332';
				yourself.
			Smalltalk at: #SystemVersion ifPresent: [:cl | | versionString |
				versionString := cl current version.
				(versionString beginsWith: 'Squeak3')
					ifTrue: [ gofer version: 'Metacello-Platform.squeak-dkh.5']].
			gofer load.
			"now load minimal installation"
			self load ]]! !

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'SeanDeNigris 6/27/2012 23:06'!
platformPackage

	Smalltalk at: #SystemVersion ifPresent: [ :sysVersion | | versionString |
		versionString := sysVersion current version.

		(versionString beginsWith: 'Squeak') ifTrue: [ 
			^ (versionString beginsWith: 'Squeak3')
				ifTrue: [ 'Metacello-Platform.squeak-dkh.5' ]
				ifFalse: [ 'Metacello-Platform.squeak-dkh.10' ] ].
		
		(versionString beginsWith: 'Pharo') ifTrue: [ 
			^ (versionString beginsWith: 'Pharo2')
				ifTrue: [ 'Metacello-Platform.pharo20-SeanDeNigris.28' ]
				ifFalse: [ 'Metacello-Platform.pharo-dkh.27' ] ] ].
	^ nil.! !

!ConfigurationOfMetacello class methodsFor: 'accessing' stamp: 'dkh 6/12/2012 09:37:55.692'!
project

	^self new project! !

!ConfigurationOfMetacello class methodsFor: 'development support' stamp: 'dkh 6/12/2012 09:37:55.692'!
releaseDevelopmentVersion: commitMessage
	"Release #development version: set version blessing to #release, update the #development and #stable symbolic version methods and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0-beta.28.3'"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfMetacello class methodsFor: 'metacello release process' stamp: 'dkh 6/12/2012 09:37:55.692'!
releaseMetacelloVersion
	"self releaseMetacelloVersion"
	
	self 
		copyConfigToRepos;
		backupToSqueakSource;
		yourself! !

!ConfigurationOfMetacello class methodsFor: 'development support' stamp: 'dkh 6/12/2012 09:37:55.692'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note that Metacello 1.0-beta.28 is needed and is currently unstable and in development"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfMetacello class methodsFor: 'unloading' stamp: 'dkh 6/12/2012 09:37:55.692'!
unloadMetacello

	| gofer |
	gofer := Gofer new.
	MCWorkingCopy allManagers do: [:wc |
		((wc packageName beginsWith: 'Metacello') or: [ wc packageName beginsWith: 'OB-Metacello' ])
			ifTrue: [ gofer package: wc packageName ]].
	gofer unload.! !

!ConfigurationOfMetacello class methodsFor: 'development support' stamp: 'dkh 6/12/2012 09:37:55.692'!
validate
    "self validate"

    self ensureMetacello.
    ^ ((Smalltalk at: #'MetacelloToolBox') validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta00: spec 
	<version: '1.0-beta.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Default configuration ... loads latest versions of all packages'.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec 
			package: 'Gofer' with: [
				spec repository: 'http://source.lukas-renggli.ch/flair' ];
			package: 'Metacello-Core' with: [
				spec includes: #('Metacello-MC' 'Metacello-Platform') ];
			package: 'Metacello-MC' with: [
				spec requires: #('Gofer') ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC') ];
			package: 'Metacello-ConfigTests' with: [
				spec requires: #('Metacello-MC') ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC') ];
			package: 'Metacello-ReferenceTests' with: [
				spec requires: #('Metacello-Reference') ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform') ].
		spec
			group: 'default' with: #('Metacello-Core' 'Metacello-Reference');
			group: 'UI' with: #('Metacello-Core' 'OB-Metacello'); 
			group: 'Tests' with: #('Metacello-ConfigTests' 'Metacello-ReferenceTests') ].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone'].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo'].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak' ].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta03: spec 
	<version: '1.0-beta.3-baseline' imports: #('1.0-beta.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Extensions to 1.0-beta.0-baseline: 
- ''default'' group is just the core ... class-side loaders load ''ALL'' by default
- pull in some old tests that still apply
- combine Metacello-ConfigTests into Metacello-TestsMC
- rename Metacello-ReferenceTests to Metacello-TestsReference
- recast tutorial to new API
- add Samples group (Metacello-Configuration [duh] and Seaside-Metacello-Configuration'.

		spec 
			package: 'Metacello-Tutorial' with: [
				spec requires:  #('Metacello-Core'). ];
			package: 'Metacello-TestsCore' with: [
				spec requires:  #('Metacello-Core'). ];
			package: 'Metacello-TestsMC' with: [
				spec requires:  #('Metacello-Core'). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference') ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires:  #('Metacello-Tutorial'). ];
			removePackage: 'Metacello-ConfigTests';
			removePackage: 'Metacello-ReferenceTests';
			"SAMPLE"
			package: 'ConfigurationOfMetacello' with: [
				spec repository: 'http://seaside.gemstone.com/ss/metacello' ];
			"SAMPLE"
			package: 'Seaside-Metacello-Configuration' with: [
				spec repository: 'http://seaside.gemstone.com/ss/Seaside30' ].
		spec
			group: 'default' overrides: #('Metacello-Core');
			group: 'Samples' with: #('ConfigurationOfMetacello' 'Seaside-Metacello-Configuration');
			group: 'Tests' overrides: 
				#('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC'
				  'Metacello-TestsReference'). ].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta05: spec 
	<version: '1.0-beta.5-baseline' imports: #('1.0-beta.3-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Extensions to 1.0-beta.3-baseline: 
- Samples group includes Seaside-Metacello-Configuration and GemTools-Configuraton (Metacello-Configuration should not be included ... it is always present)'.

		spec 
			package: 'GemTools-Configuraton' with: [
				spec repository: 'http://seaside.gemstone.com/ss/GLASSClient' ];
			removePackage: 'ConfigurationOfMetacello'.
		spec
			group: 'Samples' overrides: 
				#('Seaside-Metacello-Configuration' 'GemTools-Configuraton' ) ].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta11: spec 
	<version: '1.0-beta.11-baseline' imports: #('1.0-beta.3-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Removing Samples completely... Confusing I think'.

		spec 
			removePackage: 'Seaside-Metacello-Configuration';
			removePackage: 'GemTools-Configuraton';
			removePackage: 'ConfigurationOfMetacello'.
		spec
			removeGroup: 'Samples'].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta13: spec 
	<version: '1.0-beta.13-baseline' imports: #('1.0-beta.11-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'fix Metacello-MC dependency'.

		spec 
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core') ];
			yourself].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta14: spec 
	<version: '1.0-beta.14-baseline' imports: #('1.0-beta.13-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'switch gofer repositories'.

		spec 
			package: 'Gofer' with: [
				spec repository: 'http://source.lukas-renggli.ch/gofer' ];
			yourself].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta16: spec 
	<version: '1.0-beta.16-baseline' imports: #('1.0-beta.14-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'switch gofer repositories again ... use copy in Metacello going forward'.

		spec 
			package: 'Gofer' with: [
				spec repository: 'http://seaside.gemstone.com/ss/metacello' ];
			yourself].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta17: spec 
	<version: '1.0-beta.17-baseline' imports: #('1.0-beta.16-baseline')>
	
	spec for: #squeakCommon do: [
		spec 
			package: 'Metacello-TestsPlatform' with: [
				spec
					requires: #('Metacello-Platform');
					file: 'Metacello-TestsPlatform.squeakCommon'];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform')].
		
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta18: spec 
	<version: '1.0-beta.18-baseline' imports: #('1.0-beta.17-baseline')>
	
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Gofer' with: [
				spec requires: #('Monticello')];
			yourself. ].
		
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta19: spec 
	<version: '1.0-beta.19-baseline' imports: #('1.0-beta.18-baseline')>

	spec for: #'Gofer-Core' do: [
		spec
			removePackage: 'Gofer';
			package: 'Gofer-Core'  with: [
				spec repository: 'http://www.squeaksource.com/Pharo' ];
			package: 'Gofer-Tests'  with: [
				spec repository: 'http://www.squeaksource.com/Pharo' ];
			package: 'Metacello-MC' overrides: [
				spec requires: #('Gofer-Core') ];
			package: 'Metacello-TestsMC' with: [
				spec requires: #('Gofer-Tests') ];
			yourself ].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta21: spec 
	<version: '1.0-beta.21-baseline' imports: #('1.0-beta.19-baseline')>

	spec for: #'Gofer-Core' do: [
		spec
			removePackage: 'Gofer';
			package: 'Gofer-Core'  overrides: [
				spec repository: 'http://seaside.gemstone.com/ss/metacello' ];
			package: 'Gofer-Tests'  overrides: [
				spec 
					requires: 'Gofer-Core' ;
					repository: 'http://seaside.gemstone.com/ss/metacello' ];
			yourself ].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta22: spec
	<version: '1.0-beta.22-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Core' with: [
				spec includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' ). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' overrides: #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta25: spec
	<version: '1.0-beta.25-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Core' with: [
				spec includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' ). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' overrides: #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta27: spec
	<version: '1.0-beta.27-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Core' with: [
				spec includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' ). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' overrides: #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			group: 'Tutorial' with: #('Metacello-Help' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta2831: spec
	<version: '1.0-beta.28.3.1-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: 'Metacello-Base'. ];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			group: 'Tutorial' with: #('Metacello-Help' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta2833: spec
	<version: '1.0-beta.28.3.3-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: 'Metacello-Base'. ];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			group: 'Tutorial' with: #('Metacello-Help' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo1.3.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta28: spec
	<version: '1.0-beta.28-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: 'Metacello-Base'. ];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			group: 'Tutorial' with: #('Metacello-Help' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta28ea3: spec
	<version: '1.0-beta.28-ea.3-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: 'Metacello-Base'. ];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			group: 'Tutorial' with: #('Metacello-Help' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta28ea: spec
	<version: '1.0-beta.28-ea-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' ). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' overrides: #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			group: 'Tutorial' with: #('Metacello-Help' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta29: spec
	<version: '1.0-beta.29-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: 'Metacello-Base'. ];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Core' with: #('default' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo1.3.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta30: spec
	<version: '1.0-beta.30-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: 'Metacello-Base'. ];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Core' with: #('default' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo1.3.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: [
				spec 
					file: 'Metacello-Platform.gemstone';
					requires: 'Monticello'];
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'SeanDeNigris 6/22/2012 11:41'!
baseline10beta3113: spec
	<version: '1.0-beta.31.1.3-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: #('Metacello-Base' 'Metacello-Core')];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'batch' with: #('Metacello-Core' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Core' with: #('default' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://dsal.cl/squeaksource/MetacelloRepository'. ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://dsal.cl/squeaksource/MetacelloRepository'. ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://dsal.cl/squeaksource/MetacelloRepository'. ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo1.3.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: [
				spec 
					file: 'Metacello-Platform.gemstone';
					postLoadDoIt: #gemstone10beta311PostLoadDoIt;
					requires: 'Monticello'];
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'SeanDeNigris 6/27/2012 22:15'!
baseline10beta3114: spec
	<version: '1.0-beta.31.1.4-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: #('Metacello-Base' 'Metacello-Core')];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'batch' with: #('Metacello-Core' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Core' with: #('default' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://dsal.cl/squeaksource/MetacelloRepository'. ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://dsal.cl/squeaksource/MetacelloRepository'. ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://dsal.cl/squeaksource/MetacelloRepository'. ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo1.3.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo2.x' do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo20';
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: [
				spec 
					file: 'Metacello-Platform.gemstone';
					postLoadDoIt: #gemstone10beta311PostLoadDoIt;
					requires: 'Monticello'];
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 06/15/2014 13:16'!
baseline10beta3115: spec
  <version: '1.0-beta.31.1.5-baseline'>
  spec
    for: #'common'
    do: [ 
      spec blessing: #'baseline'.
      spec repository: 'http://seaside.gemtalksystems.com/ss/metacello'.
      spec
        project: 'Gofer Core'
          with: [ 
              spec
                className: 'ConfigurationOfGofer';
                versionString: '1.0-baseline';
                loads: #('Core');
                file: 'ConfigurationOfGofer';
                repository: 'http://seaside.gemtalksystems.com/ss/metacello' ];
        project: 'Gofer Tests'
          copyFrom: 'Gofer Core'
          with: [ spec loads: #('Tests') ];
        yourself.
      spec
        package: 'Metacello-Base';
        package: 'Metacello-ToolBox'
          with: [ spec requires: #('Metacello-Base' 'Metacello-Core') ];
        package: 'Metacello-Core'
          with: [ 
              spec
                requires: 'Metacello-Base';
                includes: #('Metacello-MC' 'Metacello-Platform') ];
        package: 'Metacello-MC'
          with: [ spec requires: #('Metacello-Core' 'Gofer Core') ];
        package: 'Metacello-Platform'
          with: [ spec requires: #('Metacello-MC') ];
        package: 'Metacello-Reference'
          with: [ spec requires: #('Metacello-MC') ];
        package: 'Metacello-Tutorial'
          with: [ spec requires: #('Metacello-Core') ];
        package: 'Metacello-TestsCore'
          with: [ spec requires: #('Metacello-Core') ];
        package: 'Metacello-TestsMC'
          with: [ 
              spec
                postLoadDoIt: #'testsMC10beta25PostLoadDoIt';
                requires: #('Metacello-ToolBox' 'Metacello-MC' 'Gofer Tests') ];
        package: 'Metacello-TestsReference'
          with: [ spec requires: #('Metacello-Reference') ];
        package: 'Metacello-TestsTutorial'
          with: [ spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC') ];
        package: 'OB-Metacello'
          with: [ spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox') ];
        yourself.
      spec
        group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox');
        group: 'batch' with: #('Metacello-Core');
        group: 'Base Configuration' with: #('Metacello-Base');
        group: 'Core' with: #('default');
        group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference');
        group: 'UI' with: #('OB-Metacello');
        group: 'TravisCI'
          with:
            #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference');
        group: 'Tests'
          with:
            #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference');
        yourself ].
  spec
    for: #'squeakCommon'
    do: [ 
      spec
        project: 'Help System'
          with: [ 
              spec
                className: 'ConfigurationOfHelpSystem';
                versionString: '1.0-baseline';
                loads: #('Core');
                file: 'ConfigurationOfHelpSystem';
                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
        project: 'OB'
          with: [ 
              spec
                className: 'ConfigurationOfOmniBrowser';
                versionString: '1.1-baseline';
                loads: #('Core');
                file: 'ConfigurationOfOmniBrowser';
                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
        yourself.
      spec
        package: 'Metacello-TestsPlatform'
          with: [ 
              spec
                requires: #('Metacello-Platform');
                file: 'Metacello-TestsPlatform.squeakCommon' ];
        package: 'Metacello-Help' with: [ spec requires: 'Help System' ];
        package: 'OB-Metacello' with: [ spec requires: #('OB') ];
        yourself.
      spec
        group: 'default' with: #('Metacello-Help');
        group: 'TravisCI' with: #('Metacello-TestsPlatform');
        group: 'Tests' with: #('Metacello-TestsPlatform');
        yourself ].
  spec
    for: #'pharo'
    do: [ 
      spec
        project: 'ProfStef'
          with: [ 
              spec
                className: 'ConfigurationOfProfStef';
                versionString: '1.0-baseline';
                file: 'ConfigurationOfProfStef';
                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
        yourself.
      spec
        package: 'Metacello-ProfStef'
          with: [ spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox') ];
        package: 'Metacello-TestsProfStef'
          with: [ spec requires: #('Metacello-ProfStef') ];
        package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsProfStef');
        group: 'Tutorial' with: #('Metacello-ProfStef');
        yourself ].
  spec
    for: #'pharo1.0.x'
    do: [ 
      spec
        package: 'Metacello-ProfStef'
        with: [ spec file: 'Metacello-ProfStef.toolset' ] ].
  spec
    for: #'pharo1.1.x'
    do: [ 
      spec
        package: 'Metacello-ProfStef'
        with: [ spec file: 'Metacello-ProfStef.toolset' ] ].
  spec
    for: #'pharo1.2.x'
    do: [ 
      spec
        package: 'Metacello-ProfStef'
          with: [ spec file: 'Metacello-ProfStef.toolset' ];
        package: 'Metacello-TestsMC'
          with: [ spec includes: #('Metacello-Issue3758') ];
        package: 'Metacello-Issue3758'
          with: [ spec requires: #('Metacello-TestsMC') ];
        yourself ].
  spec
    for: #'pharo1.3.x'
    do: [ 
      spec
        package: 'Metacello-TestsMC'
          with: [ spec includes: #('Metacello-Issue3758') ];
        package: 'Metacello-Issue3758'
          with: [ spec requires: #('Metacello-TestsMC') ];
        yourself ].
  spec
    for: #'pharo2.x'
    do: [ 
      spec
        package: 'Metacello-Platform' with: 'Metacello-Platform.pharo20';
        yourself ].
  spec
    for: #'squeak'
    do: [ 
      spec
        package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
        yourself ].
  spec
    for: #'gemstone'
    do: [ 
      spec
        project: 'Monticello'
          with: [ 
              spec
                className: 'ConfigurationOfGsMonticello';
                repository:
                    'http://seaside.gemtalksystems.com/ss/MetacelloRepository' ];
        project: 'OB'
          with: [ 
              spec
                className: 'ConfigurationOfGsOB';
                repository:
                    'http://seaside.gemtalksystems.com/ss/MetacelloRepository' ];
        yourself.
      spec
        package: 'Metacello-Platform'
          with: [ 
              spec
                file: 'Metacello-Platform.gemstone';
                postLoadDoIt: #'gemstone10beta311PostLoadDoIt';
                requires: 'Monticello' ];
        package: 'Metacello-TestsPlatform'
          with: [ 
              spec
                requires: #('Metacello-Platform');
                file: 'Metacello-TestsPlatform.gemstone' ];
        package: 'OB-Metacello' with: [ spec requires: #('OB') ];
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsPlatform');
        group: 'TravisCI' with: #('Metacello-TestsPlatform');
        yourself ]! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 06/28/2013 15:50'!
baseline10beta3117: spec
  <version: '1.0-beta.31.1.7-baseline'>
  spec
    for: #'common'
    do: [ 
      spec blessing: #'baseline'.
      spec repository: 'http://seaside.gemtalksystems.com/ss/metacello'.
      spec repository: 'http://smalltalkhub.com/mc/dkh/metacello/main'.
      spec
        project: 'Gofer Core'
          with: [ 
              spec
                className: 'ConfigurationOfGofer';
                versionString: '1.0-baseline';
                loads: #('Core');
                file: 'ConfigurationOfGofer';
                repository: 'http://smalltalkhub.com/mc/dkh/metacello/main';
                repository: 'http://seaside.gemtalksystems.com/ss/metacello' ];
        project: 'Gofer Tests'
          copyFrom: 'Gofer Core'
          with: [ spec loads: #('Tests') ];
        yourself.
      spec
        package: 'Metacello-Base';
        package: 'Metacello-ToolBox'
          with: [ spec requires: #('Metacello-Base' 'Metacello-Core') ];
        package: 'Metacello-Core'
          with: [ 
              spec
                requires: 'Metacello-Base';
                includes: #('Metacello-MC' 'Metacello-Platform') ];
        package: 'Metacello-MC'
          with: [ spec requires: #('Metacello-Core' 'Gofer Core') ];
        package: 'Metacello-Platform'
          with: [ spec requires: #('Metacello-MC') ];
        package: 'Metacello-Reference'
          with: [ spec requires: #('Metacello-MC') ];
        package: 'Metacello-Tutorial'
          with: [ spec requires: #('Metacello-Core') ];
        package: 'Metacello-TestsCore'
          with: [ spec requires: #('Metacello-Core') ];
        package: 'Metacello-TestsMC'
          with: [ 
              spec
                postLoadDoIt: #'testsMC10beta25PostLoadDoIt';
                requires: #('Metacello-ToolBox' 'Metacello-MC' 'Gofer Tests') ];
        package: 'Metacello-TestsReference'
          with: [ spec requires: #('Metacello-Reference') ];
        package: 'Metacello-TestsTutorial'
          with: [ spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC') ];
        package: 'OB-Metacello'
          with: [ spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox') ];
        yourself.
      spec
        group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox');
        group: 'batch' with: #('Metacello-Core');
        group: 'Base Configuration' with: #('Metacello-Base');
        group: 'Core' with: #('default');
        group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference');
        group: 'UI' with: #('OB-Metacello');
        group: 'TravisCI'
          with:
            #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference');
        group: 'Tests'
          with:
            #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference');
        yourself ].
  spec
    for: #'squeakCommon'
    do: [ 
      spec
        project: 'Help System'
          with: [ 
              spec
                className: 'ConfigurationOfHelpSystem';
                versionString: '1.0-baseline';
                loads: #('Core');
                file: 'ConfigurationOfHelpSystem';
                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
        project: 'OB'
          with: [ 
              spec
                className: 'ConfigurationOfOmniBrowser';
                versionString: '1.1-baseline';
                loads: #('Core');
                file: 'ConfigurationOfOmniBrowser';
                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
        yourself.
      spec
        package: 'Metacello-TestsPlatform'
          with: [ 
              spec
                requires: #('Metacello-Platform');
                file: 'Metacello-TestsPlatform.squeakCommon' ];
        package: 'Metacello-Help' with: [ spec requires: 'Help System' ];
        package: 'OB-Metacello' with: [ spec requires: #('OB') ];
        yourself.
      spec
        group: 'default' with: #('Metacello-Help');
        group: 'TravisCI' with: #('Metacello-TestsPlatform');
        group: 'Tests' with: #('Metacello-TestsPlatform');
        yourself ].
  spec
    for: #'pharo'
    do: [ 
      spec
        project: 'ProfStef'
          with: [ 
              spec
                className: 'ConfigurationOfProfStef';
                versionString: '1.0-baseline';
                file: 'ConfigurationOfProfStef';
                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
        yourself.
      spec
        package: 'Metacello-ProfStef'
          with: [ spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox') ];
        package: 'Metacello-TestsProfStef'
          with: [ spec requires: #('Metacello-ProfStef') ];
        package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsProfStef');
        group: 'Tutorial' with: #('Metacello-ProfStef');
        yourself ].
  spec
    for: #'pharo1.0.x'
    do: [ 
      spec
        package: 'Metacello-ProfStef'
        with: [ spec file: 'Metacello-ProfStef.toolset' ] ].
  spec
    for: #'pharo1.1.x'
    do: [ 
      spec
        package: 'Metacello-ProfStef'
        with: [ spec file: 'Metacello-ProfStef.toolset' ] ].
  spec
    for: #'pharo1.2.x'
    do: [ 
      spec
        package: 'Metacello-ProfStef'
          with: [ spec file: 'Metacello-ProfStef.toolset' ];
        package: 'Metacello-TestsMC'
          with: [ spec includes: #('Metacello-Issue3758') ];
        package: 'Metacello-Issue3758'
          with: [ spec requires: #('Metacello-TestsMC') ];
        yourself ].
  spec
    for: #'pharo1.3.x'
    do: [ 
      spec
        package: 'Metacello-TestsMC'
          with: [ spec includes: #('Metacello-Issue3758') ];
        package: 'Metacello-Issue3758'
          with: [ spec requires: #('Metacello-TestsMC') ];
        yourself ].
  spec
    for: #'pharo2.x'
    do: [ 
      spec
        package: 'Metacello-Platform' with: 'Metacello-Platform.pharo20';
        yourself ].
  spec
    for: #'squeak'
    do: [ 
      spec
        package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
        yourself ].
  spec
    for: #'gemstone'
    do: [ 
      spec
        project: 'Monticello'
          with: [ 
              spec
                className: 'ConfigurationOfGsMonticello';
                repository:
                    'http://seaside.gemtalksystems.com/ss/MetacelloRepository' ];
        project: 'OB'
          with: [ 
              spec
                className: 'ConfigurationOfGsOB';
                repository:
                    'http://seaside.gemtalksystems.com/ss/MetacelloRepository' ];
        yourself.
      spec
        package: 'Metacello-Platform'
          with: [ 
              spec
                file: 'Metacello-Platform.gemstone';
                postLoadDoIt: #'gemstone10beta311PostLoadDoIt';
                requires: 'Monticello' ];
        package: 'Metacello-TestsPlatform'
          with: [ 
              spec
                requires: #('Metacello-Platform');
                file: 'Metacello-TestsPlatform.gemstone' ];
        package: 'OB-Metacello' with: [ spec requires: #('OB') ];
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsPlatform');
        group: 'TravisCI' with: #('Metacello-TestsPlatform');
        yourself ]! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta311: spec
	<version: '1.0-beta.31.1-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: #('Metacello-Base' 'Metacello-Core')];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Core' with: #('default' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo1.3.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: [
				spec 
					file: 'Metacello-Platform.gemstone';
					postLoadDoIt: #gemstone10beta311PostLoadDoIt;
					requires: 'Monticello'];
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta31: spec
	<version: '1.0-beta.31-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: #('Metacello-Base' 'Metacello-Core')];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Core' with: #('default' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo1.3.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: [
				spec 
					file: 'Metacello-Platform.gemstone';
					requires: 'Monticello'];
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'topa 1/28/2015 00:39'!
baseline10beta321: spec
  <version: '1.0-beta.32.1-baseline'>
  spec
    for: #'common'
    do: [ 
      spec blessing: #'baseline'.
      spec repository: 'http://seaside.gemtalksystems.com/ss/metacello'.
      spec repository: 'http://smalltalkhub.com/mc/dkh/metacello/main'.
      spec
        project: 'FileTree'
          with: [ 
              spec
                className: 'ConfigurationOfFileTree';
                versionString: '1.0-baseline';
                repository: 'http://ss3.gemtalksystems.com/ss/FileTree' ];
        project: 'Gofer'
          with: [ 
              spec
                className: 'ConfigurationOfGofer';
                versionString: '1.0-baseline';
                loads: #('Core');
                repository: 'http://seaside.gemtalksystems.com/ss/metacello' ];
        project: 'Gofer Tests'
          copyFrom: 'Gofer'
          with: [ spec loads: #('Tests') ];
        yourself.
      spec
        package: 'Metacello-Base';
        package: 'Metacello-ToolBox'
          with: [ spec requires: #('Metacello-Base' 'Metacello-Core') ];
        package: 'Metacello-Core'
          with: [ 
              spec
                requires: 'Metacello-Base';
                includes: #('Metacello-MC' 'Metacello-Platform') ];
        package: 'Metacello-FileTree'
          with: [ spec requires: #('Metacello-MC' 'FileTree') ];
        package: 'Metacello-GitHub'
          with: [ spec requires: #('Metacello-MC' 'Metacello-FileTree') ];
        package: 'Metacello-MC'
          with: [ spec requires: #('Metacello-Core' 'Gofer') ];
        package: 'Metacello-Platform'
          with: [ spec requires: #('Metacello-MC') ];
        package: 'Metacello-Reference'
          with: [ spec requires: #('Metacello-MC') ];
        package: 'Metacello-Tutorial'
          with: [ spec requires: #('Metacello-Core') ];
        package: 'Metacello-TestsCore'
          with: [ spec requires: #('Metacello-Core') ];
        package: 'Metacello-TestsMCResources'
          with: [ 
              spec
                postLoadDoIt: #'testResourcePostLoadDoIt';
                includes: #('Metacello-TestsCommonMC');
                requires: #('Metacello-Core') ];
        package: 'Metacello-TestsMCCore'
          with: [ 
              spec
                requires:
                  #('Metacello-Core' 'Metacello-TestsCore' 'Metacello-ToolBox' 'Metacello-TestsMCResources') ];
        package: 'Metacello-TestsMC'
          with: [ 
              spec
                requires:
                  #('Metacello-MC' 'Gofer Tests' 'Metacello-ToolBox' 'Metacello-GitHub' 'Metacello-TestsMCResources') ];
        package: 'Metacello-TestsMCA'
          with: [ spec requires: #('Metacello-TestsMC') ];
        package: 'Metacello-TestsMCB'
          with: [ spec requires: #('Metacello-TestsMC') ];
        package: 'Metacello-TestsCommonMC'
          with: [ 
              spec
                file: 'Metacello-TestsCommonMC.common';
                requires: 'Metacello-TestsMCResources' ];
        package: 'Metacello-TestsReference'
          with: [ spec requires: #('Metacello-Reference') ];
        package: 'Metacello-TestsTutorial'
          with: [ spec requires: #('Metacello-Tutorial' 'Metacello-TestsMCResources') ];
        yourself.
      spec
        group: 'default' with: #('batch' 'Metacello-ToolBox');
        group: 'batch' with: #('Metacello-Core' 'Metacello-GitHub');
        group: 'Base Configuration' with: #('Metacello-Base');
        group: 'Core' with: #('default');
        group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference');
        group: 'UI' with: #('default');
        group: 'TravisCI_1'
          with:
            #('Metacello-TestsCore' 'Metacello-TestsReference' 'Metacello-TestsMCCore');
        group: 'TravisCI_2' with: #('Metacello-TestsMCA');
        group: 'TravisCI_3'
          with: #('Metacello-TestsMCB' 'Metacello-TestsTutorial');
        group: 'TravisCI' with: #('TravisCI_1' 'TravisCI_2' 'TravisCI_3');
        group: 'Tests'
          with:
            #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMCA' 'Metacello-TestsMCB' 'Metacello-TestsReference' 'Metacello-TestsMCCore');
        yourself ].
  spec
    for: #'squeakCommon'
    do: [ 
      spec
        project: 'HelpSystem'
          with: [ 
              spec
                className: 'ConfigurationOfHelpSystem';
                versionString: '1.0-baseline';
                loads: #('Core');
                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
        yourself.
      spec
        package: 'Metacello-TestsPlatform'
          with: [ 
              spec
                requires: #('Metacello-Platform');
                file: 'Metacello-TestsPlatform.squeakCommon' ];
        package: 'Metacello-Help' with: [ spec requires: 'HelpSystem' ];
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsPlatform');
        group: 'TravisCI_1' with: #('Metacello-TestsPlatform');
        yourself ].
  spec
    for: #'pharo'
    do: [ 
      spec
        project: 'OSProcess'
          with: [ 
              spec
                className: 'ConfigurationOfOSProcess';
                versionString: #'stable';
                repository: 'http://www.squeaksource.com/MetacelloRepository';
                repository: 'http://seaside.gemtalksystems.com/ss/metacello' ];
        project: 'ProfStef'
          with: [ 
              spec
                className: 'ConfigurationOfProfStef';
                versionString: #'stable';
                repository:
                    'http://smalltalkhub.com/mc/PharoExtras/ProfStef/main' ];
        yourself.
      spec
        package: 'Metacello-ProfStef'
          with: [ spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox') ];
        package: 'Metacello-TestsProfStef'
          with: [ spec requires: #('Metacello-ProfStef') ];
        package: 'Metacello-PharoCommonPlatform'
          with: [ spec requires: #('Metacello-MC') ];
        package: 'Metacello-Platform'
          with: [ spec requires: #('Metacello-PharoCommonPlatform') ];
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsProfStef');
        group: 'Tutorial' with: #('Metacello-ProfStef');
        yourself ].
  spec
    for: #'pharo1.x'
    do: [ 
      spec
        package: 'Metacello-Platform'
        with: [ spec 
				file: 'Metacello-Platform.pharo';
				 requires: #('OSProcess') ] ].
  spec
    for: #'pharo2.x'
    do: [ 
      spec
        project: 'OSProcess'
          with: [ spec repository: 'http://ss3.gemtalksystems.com/ss/MetaRepoForPharo20' ];
        yourself.
      spec
        package: 'Metacello-Platform'
          with: [ spec
				file: 'Metacello-Platform.pharo20';
				requires: #('OSProcess') ];
        package: 'Metacello-TestsCommonMC'
          with: [ spec file: 'Metacello-TestsCommonMC.pharo20' ];
        yourself ].
  spec
    for: #'pharo3.x'
    do: [ 
      spec removeProject: 'OSProcess'.
      spec
        package: 'Metacello-Platform'
          with: [ spec
				file: 'Metacello-Platform.pharo30' ];
        package: 'Metacello-TestsCommonMC'
          with: [ spec file: 'Metacello-TestsCommonMC.pharo20' ];
        yourself ].
  spec
    for: #'squeak'
    do: [ 
     spec
        project: 'WebClient'
          with: [ 
              spec
                className: 'ConfigurationOfWebClient';
                versionString: #stable;
                loads: #('Core');
                repository: 'http://www.squeaksource.com/MetacelloRepository';
                repository: 'http://ss3.gemtalksystems.com/ss/WebClient' ].
      spec
        package: 'SqueakSSL-Core'
 	    with: [spec repository: 'http://www.squeaksource.com/SqueakSSL'];
        package: 'Metacello-Platform'
          with: [ 
              spec
                file: 'Metacello-Platform.squeak';
                requires: #('WebClient' 'SqueakSSL-Core') ];
        yourself ].
  spec
    for: #'gemstone'
    do: [ 
      spec
        project: 'GsCore'
          with: [ 
              spec
                className: 'ConfigurationOfGsCore';
                versionString: '0.247';
                repository:
                    'http://seaside.gemtalksystems.com/ss/MetacelloRepository' ];
        project: 'GsMonticello'
          with: [ 
              spec
                className: 'ConfigurationOfGsMonticello';
                versionString: '0.242';
                repository:
                    'http://seaside.gemtalksystems.com/ss/MetacelloRepository' ];
        yourself.
      spec
        package: 'Metacello-GitHub' with: [ spec requires: #('GsCore') ];
        package: 'Metacello-Platform'
          with: [ 
              spec
                file: 'Metacello-Platform.gemstone';
                postLoadDoIt: #'gemstone10beta311PostLoadDoIt';
                requires: 'GsMonticello' ];
        package: 'Metacello-TestsPlatform'
          with: [ 
              spec
                requires: #('Metacello-Platform');
                file: 'Metacello-TestsPlatform.gemstone' ];
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsPlatform');
        group: 'TravisCI_1' with: #('Metacello-TestsPlatform');
        yourself ]! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'tfel 7/29/2014 14:51'!
baseline10beta322: spec
  <version: '1.0-beta.32.2-baseline'>
  spec
    for: #'common'
    do: [ 
      spec blessing: #'baseline'.
      spec repository: 'http://seaside.gemtalksystems.com/ss/metacello'.
      spec repository: 'http://smalltalkhub.com/mc/dkh/metacello/main'.
      spec
        project: 'FileTree'
          with: [ 
              spec
                className: 'ConfigurationOfFileTree';
                versionString: '1.0-baseline';
                repository: 'http://ss3.gemtalksystems.com/ss/FileTree' ];
        project: 'Gofer'
          with: [ 
              spec
                className: 'ConfigurationOfGofer';
                versionString: '1.0-baseline';
                loads: #('Core');
                repository: 'http://seaside.gemtalksystems.com/ss/metacello' ];
        project: 'Gofer Tests'
          copyFrom: 'Gofer'
          with: [ spec loads: #('Tests') ];
        yourself.
      spec
        package: 'Metacello-Base';
        package: 'Metacello-ToolBox'
          with: [ spec requires: #('Metacello-Base' 'Metacello-Core') ];
        package: 'Metacello-Core'
          with: [ 
              spec
                requires: 'Metacello-Base';
                includes: #('Metacello-MC' 'Metacello-Platform') ];
        package: 'Metacello-FileTree'
          with: [ spec requires: #('Metacello-MC' 'FileTree') ];
        package: 'Metacello-GitHub'
          with: [ spec requires: #('Metacello-MC' 'Metacello-FileTree') ];
        package: 'Metacello-MC'
          with: [ spec requires: #('Metacello-Core' 'Gofer') ];
        package: 'Metacello-Platform'
          with: [ spec requires: #('Metacello-MC') ];
        package: 'Metacello-Reference'
          with: [ spec requires: #('Metacello-MC') ];
        package: 'Metacello-Tutorial'
          with: [ spec requires: #('Metacello-Core') ];
        package: 'Metacello-TestsCore'
          with: [ spec requires: #('Metacello-Core') ];
        package: 'Metacello-TestsMCResources'
          with: [ 
              spec
                postLoadDoIt: #'testResourcePostLoadDoIt';
                includes: #('Metacello-TestsCommonMC');
                requires: #('Metacello-Core') ];
        package: 'Metacello-TestsMCCore'
          with: [ 
              spec
                requires:
                  #('Metacello-Core' 'Metacello-TestsCore' 'Metacello-ToolBox' 'Metacello-TestsMCResources') ];
        package: 'Metacello-TestsMC'
          with: [ 
              spec
                requires:
                  #('Metacello-MC' 'Gofer Tests' 'Metacello-ToolBox' 'Metacello-GitHub' 'Metacello-TestsMCResources') ];
        package: 'Metacello-TestsMCA'
          with: [ spec requires: #('Metacello-TestsMC') ];
        package: 'Metacello-TestsMCB'
          with: [ spec requires: #('Metacello-TestsMC') ];
        package: 'Metacello-TestsCommonMC'
          with: [ 
              spec
                file: 'Metacello-TestsCommonMC.common';
                requires: 'Metacello-TestsMCResources' ];
        package: 'Metacello-TestsReference'
          with: [ spec requires: #('Metacello-Reference') ];
        package: 'Metacello-TestsTutorial'
          with: [ spec requires: #('Metacello-Tutorial' 'Metacello-TestsMCResources') ];
        yourself.
      spec
        group: 'default' with: #('batch' 'Metacello-ToolBox');
        group: 'batch' with: #('Metacello-Core' 'Metacello-GitHub');
        group: 'Base Configuration' with: #('Metacello-Base');
        group: 'Core' with: #('default');
        group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference');
        group: 'UI' with: #('default');
        group: 'TravisCI_1'
          with:
            #('Metacello-TestsCore' 'Metacello-TestsReference' 'Metacello-TestsMCCore');
        group: 'TravisCI_2' with: #('Metacello-TestsMCA');
        group: 'TravisCI_3'
          with: #('Metacello-TestsMCB' 'Metacello-TestsTutorial');
        group: 'TravisCI' with: #('TravisCI_1' 'TravisCI_2' 'TravisCI_3');
        group: 'Tests'
          with:
            #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMCA' 'Metacello-TestsMCB' 'Metacello-TestsReference' 'Metacello-TestsMCCore');
        yourself ].
  spec
    for: #'squeakCommon'
    do: [ 
      spec
        project: 'HelpSystem'
          with: [ 
              spec
                className: 'ConfigurationOfHelpSystem';
                versionString: '1.0-baseline';
                loads: #('Core');
                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
        project: 'OSProcess'
          with: [ 
              spec
                className: 'ConfigurationOfOSProcess';
                versionString: #'stable';
                repository: 'http://www.squeaksource.com/MetacelloRepository';
                repository: 'http://seaside.gemtalksystems.com/ss/metacello' ];
        yourself.
      spec
        package: 'Metacello-TestsPlatform'
          with: [ 
              spec
                requires: #('Metacello-Platform');
                file: 'Metacello-TestsPlatform.squeakCommon' ];
        package: 'Metacello-Help' with: [ spec requires: 'HelpSystem' ];
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsPlatform');
        group: 'TravisCI_1' with: #('Metacello-TestsPlatform');
        yourself ].
  spec
    for: #'pharo'
    do: [ 
      spec
        project: 'ProfStef'
          with: [ 
              spec
                className: 'ConfigurationOfProfStef';
                versionString: #'stable';
                repository:
                    'http://smalltalkhub.com/mc/PharoExtras/ProfStef/main' ];
        yourself.
      spec
        package: 'Metacello-ProfStef'
          with: [ spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox') ];
        package: 'Metacello-TestsProfStef'
          with: [ spec requires: #('Metacello-ProfStef') ];
        package: 'Metacello-PharoCommonPlatform'
          with: [ spec requires: #('Metacello-MC') ];
        package: 'Metacello-Platform'
          with: [ spec requires: #('Metacello-PharoCommonPlatform') ];
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsProfStef');
        group: 'Tutorial' with: #('Metacello-ProfStef');
        yourself ].
  spec
    for: #'pharo1.x'
    do: [ 
      spec
        package: 'Metacello-Platform'
        with: [ spec 
				file: 'Metacello-Platform.pharo';
				 requires: #('OSProcess') ] ].
  spec
    for: #'pharo2.x'
    do: [ 
      spec
        project: 'OSProcess'
          with: [ spec repository: 'http://ss3.gemtalksystems.com/ss/MetaRepoForPharo20' ];
        yourself.
      spec
        package: 'Metacello-Platform'
          with: [ spec
				file: 'Metacello-Platform.pharo20';
				requires: #('OSProcess') ];
        package: 'Metacello-TestsCommonMC'
          with: [ spec file: 'Metacello-TestsCommonMC.pharo20' ];
        yourself ].
  spec
    for: #'pharo3.x'
    do: [ 
      spec removeProject: 'OSProcess'.
      spec
        package: 'Metacello-Platform'
          with: [ spec
				file: 'Metacello-Platform.pharo30' ];
        package: 'Metacello-TestsCommonMC'
          with: [ spec file: 'Metacello-TestsCommonMC.pharo20' ];
        yourself ].
  spec
    for: #'squeak'
    do: [
      spec
        package: 'SqueakSSL-Core'
        with: [spec repository: 'http://www.squeaksource.com/SqueakSSL'].
      spec
        package: 'WebClient-Core'
        with: [spec repository: 'http://ss3.gemstone.com/ss/WebClient'].
      spec
        package: 'Metacello-Platform'
          with: [ 
              spec
                file: 'Metacello-Platform.squeak';
                repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities';
                requires: #('WebClient-Core' 'SqueakSSL-Core') ];
        yourself ].
  spec
    for: #'gemstone'
    do: [ 
      spec
        project: 'GsCore'
          with: [ 
              spec
                className: 'ConfigurationOfGsCore';
                versionString: '0.247';
                repository:
                    'http://seaside.gemtalksystems.com/ss/MetacelloRepository' ];
        project: 'GsMonticello'
          with: [ 
              spec
                className: 'ConfigurationOfGsMonticello';
                versionString: '0.242';
                repository:
                    'http://seaside.gemtalksystems.com/ss/MetacelloRepository' ];
        yourself.
      spec
        package: 'Metacello-GitHub' with: [ spec requires: #('GsCore') ];
        package: 'Metacello-Platform'
          with: [ 
              spec
                file: 'Metacello-Platform.gemstone';
                postLoadDoIt: #'gemstone10beta311PostLoadDoIt';
                requires: 'GsMonticello' ];
        package: 'Metacello-TestsPlatform'
          with: [ 
              spec
                requires: #('Metacello-Platform');
                file: 'Metacello-TestsPlatform.gemstone' ];
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsPlatform');
        group: 'TravisCI_1' with: #('Metacello-TestsPlatform');
        yourself ]! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'topa 9/14/2017 14:14'!
baseline10beta323: spec
  <version: '1.0-beta.32.3-baseline'>
  spec
    for: #'common'
    do: [ 
      spec blessing: #'baseline'.
      spec repository: 'http://seaside.gemtalksystems.com/ss/metacello'.
      spec repository: 'http://smalltalkhub.com/mc/dkh/metacello/main'.
      spec
        project: 'FileTree'
          with: [ 
              spec
                className: 'ConfigurationOfFileTree';
                versionString: '1.0-baseline';
                repository: 'http://ss3.gemtalksystems.com/ss/FileTree' ];
        project: 'Gofer'
          with: [ 
              spec
                className: 'ConfigurationOfGofer';
                versionString: '1.0-baseline';
                loads: #('Core');
                repository: 'http://seaside.gemtalksystems.com/ss/metacello' ];
        project: 'Gofer Tests'
          copyFrom: 'Gofer'
          with: [ spec loads: #('Tests') ];
        yourself.
      spec
        package: 'Metacello-Base';
        package: 'Metacello-ToolBox'
          with: [ spec requires: #('Metacello-Base' 'Metacello-Core') ];
        package: 'Metacello-Core'
          with: [ 
              spec
                requires: 'Metacello-Base';
                includes: #('Metacello-MC' 'Metacello-Platform') ];
        package: 'Metacello-FileTree'
          with: [ spec requires: #('Metacello-MC' 'FileTree') ];
        package: 'Metacello-GitHub'
          with: [ spec requires: #('Metacello-MC' 'Metacello-FileTree') ];
        package: 'Metacello-MC'
          with: [ spec requires: #('Metacello-Core' 'Gofer') ];
        package: 'Metacello-Platform'
          with: [ spec requires: #('Metacello-MC') ];
        package: 'Metacello-Reference'
          with: [ spec requires: #('Metacello-MC') ];
        package: 'Metacello-Tutorial'
          with: [ spec requires: #('Metacello-Core') ];
        package: 'Metacello-TestsCore'
          with: [ spec requires: #('Metacello-Core') ];
        package: 'Metacello-TestsMCResources'
          with: [ 
              spec
                postLoadDoIt: #'testResourcePostLoadDoIt';
                includes: #('Metacello-TestsCommonMC');
                requires: #('Metacello-Core') ];
        package: 'Metacello-TestsMCCore'
          with: [ 
              spec
                requires:
                  #('Metacello-Core' 'Metacello-TestsCore' 'Metacello-ToolBox' 'Metacello-TestsMCResources') ];
        package: 'Metacello-TestsMC'
          with: [ 
              spec
                requires:
                  #('Metacello-MC' 'Gofer Tests' 'Metacello-ToolBox' 'Metacello-GitHub' 'Metacello-TestsMCResources') ];
        package: 'Metacello-TestsMCA'
          with: [ spec requires: #('Metacello-TestsMC') ];
        package: 'Metacello-TestsMCB'
          with: [ spec requires: #('Metacello-TestsMC') ];
        package: 'Metacello-TestsCommonMC'
          with: [ 
              spec
                file: 'Metacello-TestsCommonMC.common';
                requires: 'Metacello-TestsMCResources' ];
        package: 'Metacello-TestsReference'
          with: [ spec requires: #('Metacello-Reference') ];
        package: 'Metacello-TestsTutorial'
          with: [ spec requires: #('Metacello-Tutorial' 'Metacello-TestsMCResources') ];
        yourself.
      spec
        group: 'default' with: #('batch' 'Metacello-ToolBox');
        group: 'batch' with: #('Metacello-Core' 'Metacello-GitHub');
        group: 'Base Configuration' with: #('Metacello-Base');
        group: 'Core' with: #('default');
        group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference');
        group: 'UI' with: #('default');
        group: 'TravisCI_1'
          with:
            #('Metacello-TestsCore' 'Metacello-TestsReference' 'Metacello-TestsMCCore');
        group: 'TravisCI_2' with: #('Metacello-TestsMCA');
        group: 'TravisCI_3'
          with: #('Metacello-TestsMCB' 'Metacello-TestsTutorial');
        group: 'TravisCI' with: #('TravisCI_1' 'TravisCI_2' 'TravisCI_3');
        group: 'Tests'
          with:
            #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMCA' 'Metacello-TestsMCB' 'Metacello-TestsReference' 'Metacello-TestsMCCore');
        yourself ].
  spec
    for: #'squeakCommon'
    do: [ 
      spec
        project: 'HelpSystem'
          with: [ 
              spec
                className: 'ConfigurationOfHelpSystem';
                versionString: '1.0-baseline';
                loads: #('Core');
                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
        yourself.
      spec
        package: 'Metacello-TestsPlatform'
          with: [ 
              spec
                requires: #('Metacello-Platform');
                file: 'Metacello-TestsPlatform.squeakCommon' ];
        package: 'Metacello-Help' with: [ spec requires: 'HelpSystem' ];
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsPlatform');
        group: 'TravisCI_1' with: #('Metacello-TestsPlatform');
        yourself ].
  spec
    for: #'pharo'
    do: [ 
      spec
        project: 'OSProcess'
          with: [ 
              spec
                className: 'ConfigurationOfOSProcess';
                versionString: #'stable';
                repository: 'http://www.squeaksource.com/MetacelloRepository';
                repository: 'http://seaside.gemtalksystems.com/ss/metacello' ];
        project: 'ProfStef'
          with: [ 
              spec
                className: 'ConfigurationOfProfStef';
                versionString: #'stable';
                repository:
                    'http://smalltalkhub.com/mc/PharoExtras/ProfStef/main' ];
        yourself.
      spec
        package: 'Metacello-ProfStef'
          with: [ spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox') ];
        package: 'Metacello-TestsProfStef'
          with: [ spec requires: #('Metacello-ProfStef') ];
        package: 'Metacello-PharoCommonPlatform'
          with: [ spec requires: #('Metacello-MC') ];
        package: 'Metacello-Platform'
          with: [ spec requires: #('Metacello-PharoCommonPlatform') ];
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsProfStef');
        group: 'Tutorial' with: #('Metacello-ProfStef');
        yourself ].
  spec
    for: #'pharo1.x'
    do: [ 
      spec
        package: 'Metacello-Platform'
        with: [ spec 
				file: 'Metacello-Platform.pharo';
				 requires: #('OSProcess') ] ].
  spec
    for: #'pharo2.x'
    do: [ 
      spec
        project: 'OSProcess'
          with: [ spec repository: 'http://ss3.gemtalksystems.com/ss/MetaRepoForPharo20' ];
        yourself.
      spec
        package: 'Metacello-Platform'
          with: [ spec
				file: 'Metacello-Platform.pharo20';
				requires: #('OSProcess') ];
        package: 'Metacello-TestsCommonMC'
          with: [ spec file: 'Metacello-TestsCommonMC.pharo20' ];
        yourself ].
  spec
    for: #'pharo3.x'
    do: [ 
      spec removeProject: 'OSProcess'.
      spec
        package: 'Metacello-Platform'
          with: [ spec
				file: 'Metacello-Platform.pharo30' ];
        package: 'Metacello-TestsCommonMC'
          with: [ spec file: 'Metacello-TestsCommonMC.pharo20' ];
        yourself ].
  spec
    for: #'squeak'
    do: [ 
     spec
        package: 'Metacello-Platform'
          with: [ spec file: 'Metacello-Platform.squeak' ];
        yourself ].
  spec
    for: #( #'squeak4.1.x' #'squeak4.2.x' #'squeak4.3.x' #'squeak4.4.x' #'squeak4.5.x' )
    do: [ 
     spec
        project: 'WebClient'
          with: [ 
              spec
                className: 'ConfigurationOfWebClient';
                versionString: #stable;
                loads: #('Core');
                repository: 'http://www.squeaksource.com/MetacelloRepository';
                repository: 'http://ss3.gemtalksystems.com/ss/WebClient' ].
      spec
        package: 'SqueakSSL-Core'
 	    with: [spec repository: 'http://www.squeaksource.com/SqueakSSL'];
        package: 'Metacello-Platform'
          with: [ spec requires: #('WebClient' 'SqueakSSL-Core') ];
        yourself ].
  spec
    for: #'gemstone'
    do: [ 
      spec
        project: 'GsCore'
          with: [ 
              spec
                className: 'ConfigurationOfGsCore';
                versionString: '0.247';
                repository:
                    'http://seaside.gemtalksystems.com/ss/MetacelloRepository' ];
        project: 'GsMonticello'
          with: [ 
              spec
                className: 'ConfigurationOfGsMonticello';
                versionString: '0.242';
                repository:
                    'http://seaside.gemtalksystems.com/ss/MetacelloRepository' ];
        yourself.
      spec
        package: 'Metacello-GitHub' with: [ spec requires: #('GsCore') ];
        package: 'Metacello-Platform'
          with: [ 
              spec
                file: 'Metacello-Platform.gemstone';
                postLoadDoIt: #'gemstone10beta311PostLoadDoIt';
                requires: 'GsMonticello' ];
        package: 'Metacello-TestsPlatform'
          with: [ 
              spec
                requires: #('Metacello-Platform');
                file: 'Metacello-TestsPlatform.gemstone' ];
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsPlatform');
        group: 'TravisCI_1' with: #('Metacello-TestsPlatform');
        yourself ]! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 06/15/2014 13:17'!
baseline10beta32: spec
  <version: '1.0-beta.32-baseline'>
  spec
    for: #'common'
    do: [ 
      spec blessing: #'baseline'.
      spec repository: 'http://seaside.gemtalksystems.com/ss/metacello'.
      spec repository: 'http://www.squeaksource.com/metacello'.
      spec
        project: 'FileTree'
          with: [ 
              spec
                className: 'ConfigurationOfFileTree';
                versionString: '1.0-baseline';
                repository: 'http://ss3.gemtalksystems.com/ss/FileTree' ];
        project: 'Gofer'
          with: [ 
              spec
                className: 'ConfigurationOfGofer';
                versionString: '1.0-baseline';
                loads: #('Core');
                repository: 'http://seaside.gemtalksystems.com/ss/metacello' ];
        project: 'Gofer Tests'
          copyFrom: 'Gofer'
          with: [ spec loads: #('Tests') ];
        yourself.
      spec
        package: 'Metacello-Base';
        package: 'Metacello-ToolBox'
          with: [ spec requires: #('Metacello-Base' 'Metacello-Core') ];
        package: 'Metacello-Core'
          with: [ 
              spec
                requires: 'Metacello-Base';
                includes: #('Metacello-MC' 'Metacello-Platform') ];
        package: 'Metacello-FileTree'
          with: [ spec requires: #('Metacello-MC' 'FileTree') ];
        package: 'Metacello-GitHub'
          with: [ spec requires: #('Metacello-MC' 'Metacello-FileTree') ];
        package: 'Metacello-MC'
          with: [ spec requires: #('Metacello-Core' 'Gofer') ];
        package: 'Metacello-Platform'
          with: [ spec requires: #('Metacello-MC') ];
        package: 'Metacello-Reference'
          with: [ spec requires: #('Metacello-MC') ];
        package: 'Metacello-Tutorial'
          with: [ spec requires: #('Metacello-Core') ];
        package: 'Metacello-TestsCore'
          with: [ spec requires: #('Metacello-Core') ];
        package: 'Metacello-TestsMC'
          with: [ 
              spec
                postLoadDoIt: #'testsMC10beta25PostLoadDoIt';
                requires:
                    #('Metacello-MC' 'Metacello-TestsCore' 'Gofer Tests' 'Metacello-ToolBox') ];
        package: 'Metacello-TestsReference'
          with: [ spec requires: #('Metacello-Reference') ];
        package: 'Metacello-TestsTutorial'
          with: [ spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC') ];
        package: 'OB-Metacello'
          with: [ spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox') ];
        yourself.
      spec
        group: 'default'
          with: #('Metacello-Core' 'Metacello-ToolBox' 'Metacello-GitHub');
        group: 'batch' with: #('Metacello-Core' 'Metacello-GitHub');
        group: 'Base Configuration' with: #('Metacello-Base');
        group: 'Core' with: #('default');
        group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference');
        group: 'UI' with: #('OB-Metacello');
        group: 'TravisCI'
          with:
            #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference');
        group: 'Tests'
          with:
            #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference');
        yourself ].
  spec
    for: #'squeakCommon'
    do: [ 
      spec
        project: 'HelpSystem'
          with: [ 
              spec
                className: 'ConfigurationOfHelpSystem';
                versionString: #'1.0-baseline';
                loads: #('Core');
                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
        project: 'OmniBrowser'
          with: [ 
              spec
                className: 'ConfigurationOfOmniBrowser';
                versionString: #'stable';
                loads: #('Core');
                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
        project: 'OSProcess'
          with: [ 
              spec
                className: 'ConfigurationOfOSProcess';
                versionString: #'stable';
                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
        yourself.
      spec
        package: 'Metacello-TestsPlatform'
          with: [ 
              spec
                requires: #('Metacello-Platform');
                file: 'Metacello-TestsPlatform.squeakCommon' ];
        package: 'Metacello-Help' with: [ spec requires: 'HelpSystem' ];
        package: 'OB-Metacello' with: [ spec requires: #('OmniBrowser') ];
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsPlatform');
        group: 'TravisCI' with: #('Metacello-TestsPlatform');
        yourself ].
  spec
    for: #'pharo'
    do: [ 
      spec
        project: 'ProfStef'
          with: [ 
              spec
                className: 'ConfigurationOfProfStef';
                versionString: #'stable';
                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
        yourself.
      spec
        package: 'Metacello-ProfStef'
          with: [ spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox') ];
        package: 'Metacello-TestsProfStef'
          with: [ spec requires: #('Metacello-ProfStef') ];
        package: 'Metacello-Platform'
          with: [ 
              spec
                file: 'Metacello-Platform.pharo';
                requires: #('OSProcess') ];
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsProfStef');
        group: 'Tutorial' with: #('Metacello-ProfStef');
        yourself ].
  spec
    for: #'pharo2.x'
    do: [ 
      spec removeProject: 'OmniBrowser'.
      spec
        package: 'Metacello-Platform'
        with: [ spec file: 'Metacello-Platform.pharo20' ] ].
  spec
    for: #'squeak'
    do: [ 
      spec yourself.
      spec
        package: 'Metacello-Platform'
          with: [ 
              spec
                file: 'Metacello-Platform.squeak';
                requires: #('OSProcess') ];
        yourself ].
  spec
    for: #'gemstone'
    do: [ 
      spec
        project: 'GsCore'
          with: [ 
              spec
                className: 'ConfigurationOfGsCore';
                versionString: '0.247';
                repository:
                    'http://seaside.gemtalksystems.com/ss/MetacelloRepository' ];
        project: 'GsMonticello'
          with: [ 
              spec
                className: 'ConfigurationOfGsMonticello';
                versionString: '0.242';
                repository:
                    'http://seaside.gemtalksystems.com/ss/MetacelloRepository' ];
        project: 'OmniBrowser'
          with: [ 
              spec
                className: 'ConfigurationOfGsOB';
                versionString: #'stable';
                repository:
                    'http://seaside.gemtalksystems.com/ss/MetacelloRepository' ];
        yourself.
      spec
        package: 'Metacello-GitHub' with: [ spec requires: #('GsCore') ];
        package: 'Metacello-MC'
          with: [ spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt' ];
        package: 'Metacello-Platform'
          with: [ 
              spec
                file: 'Metacello-Platform.gemstone';
                postLoadDoIt: #'gemstone10beta311PostLoadDoIt';
                requires: 'GsMonticello' ];
        package: 'Metacello-TestsPlatform'
          with: [ 
              spec
                requires: #('Metacello-Platform');
                file: 'Metacello-TestsPlatform.gemstone' ];
        package: 'OB-Metacello' with: [ spec requires: #('OmniBrowser') ];
        yourself.
      spec
        group: 'Tests' with: #('Metacello-TestsPlatform');
        group: 'TravisCI' with: #('Metacello-TestsPlatform');
        yourself ]! !

!ConfigurationOfMetacello methodsFor: 'symbolic versions' stamp: 'dkh 9/14/2012 16:31'!
bleedingEdge: spec
    <symbolicVersion: #'bleedingEdge'>
    spec for: #'common' version: '1.0-beta.31.1.5-baseline'! !

!ConfigurationOfMetacello methodsFor: 'accessing' stamp: 'dkh 6/12/2012 09:37:55.692'!
customProjectAttributes
    "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes "

    | attributes |
    attributes := #(#'Gofer-Core').
    Smalltalk
        at: #'SystemVersion'
        ifPresent: [ :cl | 
            (cl current version beginsWith: 'Pharo')
                ifTrue: [ 
                    (cl current perform: #'highestUpdate') <= 10504
                        ifTrue: [ attributes := #(#'Gofer') ] ] ].
    ^ attributes! !

!ConfigurationOfMetacello methodsFor: 'symbolic versions' stamp: 'dkh 9/10/2012 11:55'!
development: spec
    <symbolicVersion: #'development'>
    spec for: #'common' version: #'notDefined'! !

!ConfigurationOfMetacello methodsFor: 'doits' stamp: 'dkh 6/12/2012 09:37:55.692'!
gemstone10beta24PreLoadDoIt
	"MetacelloGoferLoad>>addVersion: references an IV that no longer exists after version 292 of Metacello-MC"
	
	| wc ancestry versionNumber |
	wc := [((Smalltalk at: #GoferPackageReference) name: 'Metacello-MC') workingCopy] 
			on: Error 
			do: [:ex | ^self ].
	(ancestry := wc ancestry ancestors) isEmpty ifTrue: [ ^self ].
	versionNumber := (ancestry first name copyAfterLast: $.) asNumber.
	versionNumber > 292 ifTrue: [ ^self ].
	(Smalltalk at: #MetacelloGoferLoad)
		compileMethod: self gemstone10beta24PreLoadMethodString
		category: 'accessing'! !

!ConfigurationOfMetacello methodsFor: 'doits' stamp: 'dkh 6/12/2012 09:37:55.692'!
gemstone10beta24PreLoadMethodString

	^'addVersion: aVersion

	model addVersion: version'! !

!ConfigurationOfMetacello methodsFor: 'doits' stamp: 'dkh 6/12/2012 09:37:55.692'!
gemstone10beta311PostLoadDoIt
	(Smalltalk at: #MetacelloGemStonePlatform) initialize! !

!ConfigurationOfMetacello methodsFor: 'doits' stamp: 'dkh 6/15/2012 16:54'!
metacelloPrimeRegistry
    (Smalltalk at: #'MetacelloProjectRegistration') perform: #'primeRegistryFromImage'! !

!ConfigurationOfMetacello methodsFor: 'doits' stamp: 'dkh 12/18/2013 14:59'!
metacelloPrimeRegistryFor10beta32
  [ self metacelloPrimeRegistry ]
    on: Error
    do: [ :ex | 
      Transcript
        cr;
        show:
            'Error during #metacelloPrimeRegistry:' , ex description printString
                , 'You should rerun the command after the load completes' ]! !

!ConfigurationOfMetacello methodsFor: 'doits' stamp: 'dkh 05/07/2013 13:32'!
postLoadSqueakRestoreGlobalUnderscoreSelectors
  (Smalltalk at: #'Scanner')
    perform: #'prefAllowUnderscoreSelectors:'
    with:
      (Smalltalk at: #'MetacelloSqueakOriginalUnderscoreSelectorsPreferenceValue').
  Smalltalk
    removeKey: #'MetacelloSqueakOriginalUnderscoreSelectorsPreferenceValue'! !

!ConfigurationOfMetacello methodsFor: 'doits' stamp: 'dkh 05/07/2013 16:49'!
preLoadSqueakEnsureGlobalUnderscoreSelectors
  Smalltalk
    at: #'MetacelloSqueakOriginalUnderscoreSelectorsPreferenceValue'
    put: ((Smalltalk at: #'Scanner') perform: #'prefAllowUnderscoreSelectors').
  (Smalltalk at: #'Scanner')
    perform: #'prefAllowUnderscoreSelectors:'
    with: true.
  ($_ perform: #'tokenish')
    ifFalse: [ 
      Character
        perform: #'compile:classified:'
        with:
          'tokenish
        "Answer whether the receiver is a valid token-character--letter, digit, or
        colon."

        ^self == $_ or: [self == $: or: [self isLetter or: [self isDigit]]]'
        with: 'testing'.
      String initialize ]! !

!ConfigurationOfMetacello methodsFor: 'symbolic versions' stamp: 'topa 9/14/2017 14:09'!
previewBootstrap: spec
  "version to use when bootstrapping the Metacello Preview"

  <symbolicVersion: #'previewBootstrap'>
  spec for: #'common' version: '1.0-beta.32.3'! !

!ConfigurationOfMetacello methodsFor: 'accessing' stamp: 'dkh 9/16/2012 10:43'!
project
    ^ project
        ifNil: [ 
            "Bootstrap Metacello if it is not already loaded"
            self class ensureMetacello.
            project := (Smalltalk at: #'MetacelloMCProject') new projectAttributes: self customProjectAttributes.	"Create the Metacello project"
            (Smalltalk at: #'MetacelloVersionConstructor') on: self project: project.	"Construct the project"
            project loadType: #'linear'.	"change to #atomic if desired"
            project ]! !

!ConfigurationOfMetacello methodsFor: 'symbolic versions' stamp: 'dkh 7/23/2013 09:48'!
stable: spec
  <symbolicVersion: #'stable'>
  spec for: #'common' version: '1.0-beta.31.1.8'! !

!ConfigurationOfMetacello methodsFor: 'doits' stamp: 'dkh 07/17/2013 09:20'!
testResourcePostLoadDoIt
  "reset test resources"

  #(#'MetacelloAlternateResource' #'MetacelloAtomicConfigurationResource' #'MetacelloAtomicMonticelloResource' #'MetacelloConfigurationResource' #'MetacelloMonticelloResource' #'MetacelloScriptingResource' #'MetacelloIssue108Resource')
    do: [ :className | Smalltalk at: className ifPresent: [ :cls | cls reset ] ]! !

!ConfigurationOfMetacello methodsFor: 'doits' stamp: 'dkh 07/17/2013 09:20'!
testsMC10beta25PostLoadDoIt
  "reset test resources"

  self testResourcePostLoadDoIt! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta0: spec
	<version: '1.0-beta.0' imports: #('1.0-beta.0-baseline')>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Beta release introducing the shiny new API'.
		spec author: 'dkh'.
		spec timestamp: '10/9/2009 14:13'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.64';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.266';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.194';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.11';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.24';
			package: 'Metacello-ConfigTests' with: 'Metacello-ConfigTests-dkh.6';
			package: 'Metacello-ReferenceTests' with: 'Metacello-ReferenceTests-dkh.1'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.1'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta10: spec
	<excludedValidationIssues: #('1.0-beta.10' #(noVersionSpecified))>
	<version: '1.0-beta.10' imports: #('1.0-beta.5-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- GemStone-specific mods
- improve error message for missing import
- fix a couple of bugs in spawn new version
- if versionString is not specified in project reference, use #latestVersion of the project
- ''Update Package Method'' command updates the versionString for project reference to #currentVersion of the project
- ''Spawn New Version'' command spawns entry for proejct reference using #currentVersion of the project
- latest version of configuration package is loaded if the project reference refers to a version whose blessing is #development
- refactor #saveProject
- add #transact: to platform to support GemStone optional transactions
- define querying protocol (public access)
- use literal arrays instead of array constructors _everywhere_
- clean up printing
- refine querying API
- extend tutorial to cover querying API
'.
		spec author: 'dkh'.
		spec timestamp: '10/25/2009 11:34'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.70';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.285';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.222';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.29';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.7'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta11: spec
	<version: '1.0-beta.11' imports: #('1.0-beta.11-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '- pick up latest Gofer package
- fix a project version loading bug
- printing fix
- fix an update packages bug
- adjust working version package name calculation
- fix current version package name calculation (http://code.google.com/p/metacello/issues/detail?id=4)
- doits bugfix
- fix a project reference project package bug
- add ''Load Latest Packages'' OB command
- remove Samples group
- save packages fix
- must be able to load packages that use directory repositories
- GemStone/GLASS support'.
		spec author: 'dkh'.
		spec timestamp: '10/31/09 11:03:31'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.76';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.294';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.239';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.32';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #'gemstone' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.7'.].
	spec for: #'pharo' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta12: spec
	<version: '1.0-beta.12' imports: #('1.0-beta.11-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '-convert to using ConfigurationOfMetacello convention
- fix updateRepositories bug (update repository for loaded packages only)
- #repositoryFor:from: ... more GLASS support
- record last version loaded and list of packages loaded for each configuration (optional)
- use last list of packages loaded last when loading packages using tools
- improve promptForVersion algorithm to show current version and reduce version list to logical choices
- fix version number bug when version is empty. add tests
'.
		spec author: 'dkh'.
		spec timestamp: '11/03/09 11:07:27'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.76';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.295';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.245';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.37';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #'gemstone' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.7'.].
	spec for: #'pharo' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta13: spec
	<version: '1.0-beta.13' imports: #('1.0-beta.13-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix a bug in current version algorithm
- improve current version algorithm
- pick up latest Gofer
'.
		spec author: 'dkh'.
		spec timestamp: '11/5/2009 15:46'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.77';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.300';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.249';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.37';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.7'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta14: spec
	<version: '1.0-beta.14' imports: #('1.0-beta.14-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '- improve handling of #development project references. Loader is responsible for ensuring that #development projects have latest package loaded.
- use latest Gofer
- skip automatic loading of packages when working copy #needsSaving
- better loop termination logic for packageSpecsInLoadOrder
- fix logic for loading latest version of a project when versionString is not set (use latest, then last version)
- collect repositories from just the packages (ignoring projects) ... affects load latest logic
- fix #promptForVersion: ... include #development versions in listing
- GemStone attributes, now may include: #gemstone #''gs2.x'' #''gs2.3.x'' #''gs2.4.x'' and #''gs3.x'' for finer grainded resolution of Stone version
- fix a package loading logic bug found by Doru (loading latest)'.
		spec author: 'dkh'.
		spec timestamp: '11/16/2009 15:02'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.83';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.302';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.256';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.38';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #'gemstone' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.9'.].
	spec for: #'pharo' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta15: spec
	<version: '1.0-beta.15' imports: #('1.0-beta.14-baseline' )>

	spec for: #common do: [
		spec blessing: #development.
		spec description: '- fix ''Spawn New Version'' command
- tweak packageSpec shortcut printing - fine tune use of #overrides:'.
		spec author: 'dkh'.
		spec timestamp: '11/21/2009 11:49'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.83';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.302';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.258';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.37';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.9'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta16: spec
	<version: '1.0-beta.16' imports: #('1.0-beta.16-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '- put Gofer package in Metacello repository'.
		spec author: 'dkh'.
		spec timestamp: '12/01/09 16:22:42'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.83';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.302';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.259';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.37';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #'gemstone' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.9'.].
	spec for: #'pharo' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta17: spec
	<version: '1.0-beta.17' imports: #('1.0-beta.17-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix a branch name problem for working copies
- fine tune the ''Update Package Methods'' algorithm
- fix Issue 3: http://code.google.com/p/metacello/issues/detail?id=3 ''Save Packages'' save new
- fix Issue 12: http://code.google.com/p/metacello/issues/detail?id=12 Wait cursor during load
- fix Issue 14: http://code.google.com/p/metacello/issues/detail?id=14 Ftp repository for Pharo & Squeak
- fix Issue 19: http://code.google.com/p/metacello/issues/detail?id=19 Bug in Spawn New Version
'.
		spec author: 'dkh'.
		spec timestamp: '12/9/2009 11:13'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.83';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.306';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.268';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.19';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.38';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.5';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.12';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.9'.].
	spec for: #squeakCommon do: [
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.9'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta18: spec
	<version: '1.0-beta.18' imports: #('1.0-beta.18-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- implement MetacelloVersion>>isPossibleBaseline
- fix currentVersion when no packages or projects are in play
- fix a Spawn New Version bug
- allow for a nil #versionString spec in projects
- fix Issue 14: http://code.google.com/p/metacello/issues/detail?id=14 Ftp repository for Squeak only
- fix Issue 18: http://code.google.com/p/metacello/issues/detail?id=18 #linear default loadType
- fix Issue 21: http://code.google.com/p/metacello/issues/detail?id=21 optional blessing for Spawn New Version
- fix Issue 22: http://code.google.com/p/metacello/issues/detail?id=22 Better filter for Branch blessing and lastVersion
- fix Issue 23: http://code.google.com/p/metacello/issues/detail?id=23 Use Gofer batch commit for Save Packages
- fix Issue 26: http://code.google.com/p/metacello/issues/detail?id=26 New version of Gofer breaks Metacello
- port to latest version of Gofer (Gofer-lr.109)'.
		spec author: 'dkh'.
		spec timestamp: '12/29/2009 16:17'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.109';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.311';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.281';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.20';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.6';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.3';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.15';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.235'.
		spec 
			package: 'Gofer' with: 'Gofer-dkh.105';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.279';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.10'.].
	spec for: #squeakCommon do: [
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.9'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.4'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta191: spec
	<excludedValidationIssues: #('1.0-beta.19.1' #(noVersionSpecified))>
	<version: '1.0-beta.19.1' imports: #('1.0-beta.19-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix Issue 39: http://code.google.com/p/metacello/issues/detail?id=39 "WB at end of ConfigurationOfPharo load"
'.
		spec author: 'dkh'.
		spec timestamp: '1/8/2010 14:45'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.319';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.292';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.26';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.11';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.3';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.26';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #'Gofer-Core' do: [
		spec package: 'Gofer-Core' with: 'Gofer-Core-AdrianLienhard.114'.].
	spec for: #Gofer do: [
		spec package: 'Gofer' with: 'Gofer-lr.109'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.11'.].
	spec for: #squeakCommon do: [
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.11'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.4'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta19: spec
	<excludedValidationIssues: #('1.0-beta.19' #(noVersionSpecified))>
	<version: '1.0-beta.19' imports: #('1.0-beta.19-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- "Pure" Refactoring of MetacelloVersionConstructor>>on: (Danie Roux)
- fix Issue 7: http://code.google.com/p/metacello/issues/detail?id=7 "#repositoryOverrides: should be in MetacelloMCVersion"
- fix Issue 13: http://code.google.com/p/metacello/issues/detail?id=13 "more than one repository per package"
- fix Issue 16: http://code.google.com/p/metacello/issues/detail?id=16 "version level predoit/postdoit"
- fix Issue 20: http://code.google.com/p/metacello/issues/detail?id=20 "validation in #postLoadDoIt:/#preLoadDoit:"
- fix Issue 28: http://code.google.com/p/metacello/issues/detail?id=28 "supplyingAnswers: attribute for packages"
- fix Issue 30: http://code.google.com/p/metacello/issues/detail?id=30 "Imported version names"
- fix Issue 33: http://code.google.com/p/metacello/issues/detail?id=33 "ensureMetacello should do full bootstrap"
- fix Issue 38: http://code.google.com/p/metacello/issues/detail?id=38 "Metacello load fails on Squeak"
- port Gofer-lr.109 to GemStone
- stop caching packages in Pharo ... can cause trouble if repository off-line
- fix problems with GemStone Metacello when runnng without OB
- make error handler for #do:displaying: a little more specific 
- fix a problem when a second version of a package is being requested during atomic load. Must override with newer package.
- run with pre and post 10504 Pharo images
'.
		spec author: 'dkh'.
		spec timestamp: '1/8/2010 11:12'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.319';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.292';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.26';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.11';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.3';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.26';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #'Gofer-Core' do: [
		spec package: 'Gofer-Core' with: 'Gofer-Core-AdrianLienhard.114'.].
	spec for: #Gofer do: [
		spec package: 'Gofer' with: 'Gofer-lr.109'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.11'.].
	spec for: #squeakCommon do: [
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.10'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.4'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta1: spec
	<version: '1.0-beta.1' imports: #('1.0-beta.0-baseline')>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Bugfixes:
- change base version name for spawn method
- make sure author and timestamp included by spawn 
- fix file duplication for spawn method'.
		spec author: 'dkh'.
		spec timestamp: '10/10/2009 14:58'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.64';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.268';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.196';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.12';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.25';
			package: 'Metacello-ConfigTests' with: 'Metacello-ConfigTests-dkh.7';
			package: 'Metacello-ReferenceTests' with: 'Metacello-ReferenceTests-dkh.1'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.1'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta20: spec
	<excludedValidationIssues: #('1.0-beta.20' #(noVersionSpecified))>
	<version: '1.0-beta.20' imports: #('1.0-beta.19-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- tests for nested #for:do: statements
- fix Issue 40: http://code.google.com/p/metacello/issues/detail?id=40 "Tight package/repository coordination lost"
- take full advantage of Gofer repository caching
- more tests to ensure expected loading behavior
- typos fixed in Tutorial (Torsten)
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '1/14/2010 09:45'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.319';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.296';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.26';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-tbn.19';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.11';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.3';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.29';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #'Gofer-Core' do: [
		spec package: 'Gofer-Core' with: 'Gofer-Core-AdrianLienhard.114'.].
	spec for: #Gofer do: [
		spec package: 'Gofer' with: 'Gofer-lr.109'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.11'.].
	spec for: #squeakCommon do: [
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.11'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.4'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta21: spec
	<version: '1.0-beta.21' imports: #('1.0-beta.21-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix new tests so that they run on GemStone and don''t collide with existing packages
- fix Issue 41: http://code.google.com/p/metacello/issues/detail?id=41 "Trouble with nested ProgressInitiationException in certain circumstances"
- fix Issue 42: http://code.google.com/p/metacello/issues/detail?id=42 "ConfigurationOfSeaside* should use supplyingAnswers:"
- fix Issue 43: http://code.google.com/p/metacello/issues/detail?id=43 "Eliminate use of #versionInfoFor:from:do: "
- Metacello now uses Gofer for all of its interactions with Monticello (a few pockets of workingCopy still exist:)
- pick up latest Gofer-Core-lr.115 and Gofer-Tests
- some more version caching for speed
- better workingCopy resolution for MetacelloCachingGoferResolvedReference
- adjust tests - no longer inheriting pragmas ... too expensive
- introduce valueSupplyingMetacelloAnswers: to work around Pharo Issue 1824 http://code.google.com/p/pharo/issues/detail?id=1824
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '1/16/2010 12:47'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.321';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.302';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.26';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-tbn.19';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.11';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.3';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.34';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #'Gofer-Core' do: [
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core-lr.115';
			package: 'Gofer-Tests' with: 'Gofer-Tests-lr.113'.].
	spec for: #Gofer do: [
		spec package: 'Gofer' with: 'Gofer-lr.113'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.12'.].
	spec for: #squeakCommon do: [
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.12'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.4'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta22: spec
	<version: '1.0-beta.22' imports: #('1.0-beta.22-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix Issue 36: http://code.google.com/p/metacello/issues/detail?id=36 "Use ConfigurationOfOB for Metacello"
- fix Issue 49: http://code.google.com/p/metacello/issues/detail?id=49 "occassional load of older versions of projects"
- fix Issue 52: http://code.google.com/p/metacello/issues/detail?id=52 "preload/postload for groups and projects"
- MetacelloMCVersion>>resolveToLoadableSpecs: added to supplement query API
- support for Metaceller
- fix a bug in MetacelloMCProjectSpec>>resolveToAllPackagesIn:visited: when the project spec doesn''t have a versionString specified
- ProfStef tutorial (MetacelloCreateConfigurationTutorial)
- latest Gofer (Gofer-Core-lr.116 and Gofer-Tests-lr.115)
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '1/25/2010 14:19'.
		spec 
			project: 'Gofer Core' with: '1.0';
			project: 'Gofer Tests' with: '1.0'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.328';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.312';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.28';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-tbn.19';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.13';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.3';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.43';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.13'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.12'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.4'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta23: spec
	<version: '1.0-beta.23' imports: #('1.0-beta.22-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '- port to Squeak3.9.1-final-7075, Squeak3.10.2-7179-basic, Squeak3.10.2-Trunk-091128 and Squeak3.11-8931-alpha
- add #unloadMetacello to MetacelloConfigTemplate
- fix Issue25 : http://code.google.com/p/metacello/issues/detail?id=25 "currentVersion cache is too sticky ..."
- full frontal assault on findCurrentVersion and currentVersion algorithms ... corner implementation with a brigage of tests
- fix a bug in GoferResolvedReference>>compare:using: related to branch comparison found during frontal assault!!
- version #versionStatus provides additional info for using currentVersion
- deleted a bunch of methods (redundant,  confusing, not interesting and no longer used):
  - MetacelloVersion>>isCurrentCovering:
  - MetacelloProject>>currentVersionComparison:to:covering:
  - MetacelloProject>>currentVersionCovering:
  - MetacelloProject>>findCurrentVersion
  - MetacelloMCVersionSpec>>isCurrentCovering:
  - MetacelloMCVersionSpec>>isPartiallyCurrentAgainst:
  - MetacelloMCProjectSpec>>isCurrent
  - MetacelloProjectReferenceSpec>>compareVersionForLoad:using:
  - MetacelloAbstractPackageSpec>>compareVersionForLoad:using:
  - MetacelloMCVersionSpec>>isPartiallyCurrentFor:
  - MetacelloProjectReferenceSpec>>isPartiallyCurrentUsing:
  - MetacelloMCProjectSpec>>comparePartialVersion:using:
  - MetacelloProject>>partialVersionComparison:to:covering:
  - MetacelloMCProject>>projectPackage
  - MetacelloMCVersionSpec>>currentVersionComparison:covering:
  - MetacelloMCVersion>>currentVersionComparison:covering:
  - MetacelloVersion>>currentVersionComparison:covering:
  - MetacelloProjectReferenceSpec>>isPartiallyCurrentUsing:
  - MetacelloMCProjectSpec>>compareVersionForLoad:using:
  - MetacelloMCVersionSpec>>isCurrent
  - MetacelloPackageSpec>>compareVersion:using:
  - MetacelloPackageSpec>>isCurrentUsing:
  - MetacelloMCProjectSpec>>compareVersion:using:
  - MetacelloMCProjectSpec>>isCurrentUsing:
  - MetacelloAbstractPackageSpec>>isCurrentUsing:
  - MetacelloGroupSpec>>isCurrentUsing:
  - MetacelloProjectReferenceSpec>>isCurrentUsing:
  - MetacelloProject>>currentVersionComparison:to:
  - MetacelloVersion>>isCurrent
  - MetacelloVersionSpec>>isCurrent
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '02/10/10 09:56:41'.
		spec 
			project: 'Gofer Core' with: '1.0';
			project: 'Gofer Tests' with: '1.0'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.348';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.332';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.28';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-tbn.19';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.13';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.66';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.14'.].
	spec for: #'squeakCommon' do: [
		spec project: 'OB' with: '1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.13'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta2401: spec
	<version: '1.0-beta.24.0.1' imports: #('1.0-beta.22-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'patched'.
		spec description: 'picked up from patched 1.0-beta.24 from allen for GLASS 1.0-beta.7.1 on GemStone 3.0'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '7/16/2010 12:56'.
		spec 
			project: 'Gofer Core' with: '1.0.1';
			project: 'Gofer Tests' with: '1.0.1'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-ao.350';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.334';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.28';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-tbn.19';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.13';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.66';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.15'.].
	spec for: #'squeakCommon' do: [
		spec project: 'OB' with: '1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.13'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta241: spec
	<version: '1.0-beta.24.1' imports: #('1.0-beta.22-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix Issue 66: http://code.google.com/p/metacello/issues/detail?id=66 "loading latest broken by new code in 1.0-beta.24"'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '3/17/2010 11:26'.
		spec 
			project: 'Gofer Core' with: '1.0.1';
			project: 'Gofer Tests' with: '1.0.1'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-Dalehenrichs.349';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.Issue66.335';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.28';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-tbn.19';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.13';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.66';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.15'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.13'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta24: spec
	<version: '1.0-beta.24' imports: #('1.0-beta.22-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '- fix a bug in MetacelloMCProjectSpec>>compareCurrentVersion:targetVersionStatus:using: related when calculating current version against a non-standard loader
- tweak the loader API a bit for GemStone (performance improvements)
- tweak transcript info for atomic load
- start using Gofer 1.0.1
- adjust conditions that lead to a load conflict error
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '02/12/10 14:44:01'.
		spec 
			project: 'Gofer Core' with: '1.0.1';
			project: 'Gofer Tests' with: '1.0.1'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-Dalehenrichs.349';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.335';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.28';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-tbn.19';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.13';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.66';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.15'.].
	spec for: #'squeakCommon' do: [
		spec project: 'OB' with: '1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.13'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta251: spec
	<version: '1.0-beta.25.1' imports: #('1.0-beta.25-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix Issue 67: http://code.google.com/p/metacello/issues/detail?id=67 "blessing not generated by MetacelloVersionConstructor>>spawnPackageMethodIn: category: named: sourceVersion: targetVersion: blessing:"'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '3/23/2010 19:16'.
		spec 
			project: 'Gofer Core' with: '1.0.2';
			project: 'Gofer Tests' with: '1.0.2'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.360';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.386';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.29';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.55';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.14';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.90';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta25: spec
	<version: '1.0-beta.25' imports: #('1.0-beta.25-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- pick up Gofer 1.0.2
- fix Issue 10: http://code.google.com/p/metacello/issues/detail?id=10 "''save packages'' should recurse through projects"
- fix Issue 24: http://code.google.com/p/metacello/issues/detail?id=24 "Gofer #fetch support"
- fix Issue 31: http://code.google.com/p/metacello/issues/detail?id=31 "Handle boundary between #atomic and #linear loads ..."
- fix Issue 32: http://code.google.com/p/metacello/issues/detail?id=32 "Connect repositories as MCServerDirectory rather than MCDirectory"
- fix Issue 48: http://code.google.com/p/metacello/issues/detail?id=48 "Should have #loadReport message for loader..."
- fix Issue 56: http://code.google.com/p/metacello/issues/detail?id=56 "save configurtion that uses Gofer>>commit:"
- fix Issue 57: http://code.google.com/p/metacello/issues/detail?id=57 "specificy method category for version category in Metacello version constructor"
- fix Issue 58: http://code.google.com/p/metacello/issues/detail?id=58 "make #file: optional in project reference specification"
- fix Issue 59: http://code.google.com/p/metacello/issues/detail?id=59 "repository overrides should be used for MetacelloPackageSpec>>load"
- fix Issue 60: http://code.google.com/p/metacello/issues/detail?id=60 "bypass progress bars...."
- fix Issue 64: http://code.google.com/p/metacello/issues/detail?id=64 "update package methods has extra file entry"
- fix Issue 66: http://code.google.com/p/metacello/issues/detail?id=66 "loading latest broken by new code in 1.0-beta.24" [MERGE]
- #fetch and #fetch: added to MetacelloMcVersion. #fetch and #fetch: correspond to #load and #load: but only download the mcz files to a cacheRepository (controlled by version #loadPolicy)
- #fetchProject, #fetchProject:, #updateProject: added to support direct fetch of a project (ala #updateProject)
- implement version #record/#record:
- implement version #silently: for Issue 60
- implement non-interactive commit support using gofer: MetacelloMCProject>>goferCommitProject:, MetacelloPackageSpec>>goferCommitPackage:
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '3/23/2010 15:24'.
		spec 
			project: 'Gofer Core' with: '1.0.2';
			project: 'Gofer Tests' with: '1.0.2'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.358';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.386';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.29';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.55';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.14';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.90';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta261: spec
	<version: '1.0-beta.26.1' imports: #('1.0-beta.25-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix and test coverage for bug involving a postload doit with linear load nested inside an atomic load
- when loading a project reference, do not load mcz files that are older than the currently loaded mcz files (implicit version request). Older files will be loaded if directly referenced from the project being loaded (explicit version request).
- add RETRY logic to handle HTTP droppage
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '5/12/2010 12:19'.
		spec 
			project: 'Gofer Core' with: '1.0.2';
			project: 'Gofer Tests' with: '1.0.2'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.361';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.404';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.29';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.55';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.14';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.98';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta262: spec
	<version: '1.0-beta.26.2' imports: #('1.0-beta.25-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- Pharo1.1 compat for OB-Metacello
- fix Issue 77: http://code.google.com/p/metacello/issues/detail?id=77 "later version of Project reference not loaded after old version already loaded"
- add MetacelloFetchingMCSpecLoader>>printOn: that prints out loadDirective, thus restoring correct #printOn: behavior for MetacelloNullRecordingMCSpecLoader since tutorial depends upon it..
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '5/21/2010 16:26 '.
		spec 
			project: 'Gofer Core' with: '1.0.2';
			project: 'Gofer Tests' with: '1.0.2'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.361';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.407';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.29';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.56';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.14';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.99';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta263: spec
	<version: '1.0-beta.26.3' imports: #('1.0-beta.25-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix Issue 81: http://code.google.com/p/metacello/issues/detail?id=81 "wrong mcz file can be loaded when mcz file has Monticello dependencies"
- fix Issue 82: http://code.google.com/p/metacello/issues/detail?id=82 "Metacello and (Windows) file repositories"
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '6/11/2010 11:26'.
		spec 
			project: 'Gofer Core' with: '1.0.2';
			project: 'Gofer Tests' with: '1.0.2'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-tbn.362';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.409';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.30';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.56';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.15';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.102';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta26: spec
	<version: '1.0-beta.26' imports: #('1.0-beta.25-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- put comment in MetacelloMCProject>>#updateProject to warn about refreshing instance.
- helper messages: #cacheRepository: and #ignoreImage: added to MetacelloMCVersion
- refactor directive hierarchy for post/pre Load directives add #postLoadDo: and #preLoadDo: to round out API
- clean up null recording loader with respect to fetch and post/pre load doits
- directives weren''t being created correctly for post/pre load doits on packages .... now they are
- ConfigurationOfMetacello class>>alternateEnsureMetacello to be used if GemSource repository is inaccessible
- assorted tests
- #fetchPackage: added to MetacelloPackageSpec taking a MetacelloLoaderPolicy like #fetchProject: for MetacelloMCProjectSpec
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '4/12/2010 14:27'.
		spec 
			project: 'Gofer Core' with: '1.0.2';
			project: 'Gofer Tests' with: '1.0.2'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.361';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.393';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.29';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.55';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.14';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.92';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta271: spec
	<version: '1.0-beta.27.1' imports: #('1.0-beta.27-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix for Issue 86 (http://code.google.com/p/metacello/issues/detail?id=86) "project references that are supersets of a loaded project reference appear to be partially loaded"'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '6/24/2010 20:06'.
		spec 
			project: 'Gofer Core' with: '1.0.2.1';
			project: 'Gofer Tests' with: '1.0.2.1'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.363';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.417';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.56';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.16';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.106';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-tbn.3'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta272: spec
	<version: '1.0-beta.27.2' imports: #('1.0-beta.27-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- OBCmdMetacello >> isActive used #and:and which is deprecated in Pharo 1.1rc4'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '7/5/2010 09:31'.
		spec 
			project: 'Gofer Core' with: '1.0.2.1';
			project: 'Gofer Tests' with: '1.0.2.1'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.363';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.417';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.57';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.16';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.106';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-tbn.3'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta273: spec
	<version: '1.0-beta.27.3' imports: #('1.0-beta.27-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '- fix for Issue 90: http://code.google.com/p/metacello/issues/detail?id=90 "includes: aglgorithm not aggressive enough"
- fix for Issue 92: http://code.google.com/p/metacello/issues/detail?id=92 "Trait does not understand #isMetacelloConfig"
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '7/29/2010 15:56'.
		spec 
			project: 'Gofer Core' with: '1.0.2.1';
			project: 'Gofer Tests' with: '1.0.2.1'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.364';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.417';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.58';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.16';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.107';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-tbn.3'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta274: spec
	<version: '1.0-beta.27.4' imports: #('1.0-beta.27-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: 'fix bugs when trying to stash packages and configurations into a repository.
- fix Issue 79: http://code.google.com/p/metacello/issues/detail?id=79 "OB-Metacello should use MetacelloMCProjectSpec>>loadVersion: style default packages instead of lastMetacelloVersionLoad"
- best fix for Issue 92: http://code.google.com/p/metacello/issues/detail?id=92 "Trait does not understand #isMetacelloConfig"
- fix Issue 93: http://code.google.com/p/metacello/issues/detail?id=93 "poor error message when failing to resolve a package in a repository"
- fix Issue 94: http://code.google.com/p/metacello/issues/detail?id=94 "lastVersion vs latestVersion"
- fix Issue 95: http://code.google.com/p/metacello/issues/detail?id=95 "Infinite project reference loop"
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '8/31/2010 15:07'.
		spec 
			project: 'Gofer Core' with: '1.0.2.1';
			project: 'Gofer Tests' with: '1.0.2.1'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.366';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.428';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.21';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.60';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.16';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.114';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.9'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-tbn.3'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta275: spec
	<version: '1.0-beta.27.5' imports: #('1.0-beta.27-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- fixes needed for new bootstrapping scheme in GemStone3.0
- stop using deprecated in Pharo1.2 methods (sortBy:)
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '11/11/2010 11:29'.
		spec 
			project: 'Gofer Core' with: '1.0.2.1';
			project: 'Gofer Tests' with: '1.0.2.1'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.390';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.445';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.21';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.60';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.16';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.13';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.114';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.9'.].
	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.239'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-tbn.3'.].
	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta276: spec
	<version: '1.0-beta.27.6' imports: #('1.0-beta.27-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- fix a bug that prevented gofer from resolving packages in http://www.squeaksource.com/Swazoo'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '12/13/2010 16:45'.
		spec 
			project: 'Gofer Core' with: '1.0.2.2';
			project: 'Gofer Tests' with: '1.0.2.2'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.390';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.445';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.21';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.60';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.16';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.13';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.114';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.9'.].
	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.239'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-tbn.3'.].
	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta27: spec
	<version: '1.0-beta.27' imports: #('1.0-beta.27-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- include Metacello-Help from Torsten
- test case confirming that group name can be used "anywhere that project/package name can be used"
- fix Issue 85: http://code.google.com/p/metacello/issues/detail?id=85 "Metacello should load from alternate repository"
- pick up OB 1.1.4 for Pharo 1.1 compat
- redundant repository for Gofer too
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '6/15/2010 11:02'.
		spec 
			project: 'Gofer Core' with: '1.0.2.1';
			project: 'Gofer Tests' with: '1.0.2.1'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.363';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.415';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.56';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.16';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.103';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-tbn.3'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta281: spec
	<version: '1.0-beta.28.1' imports: #('1.0-beta.28-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- fix MetacelloProject>>stableVersion and MetacelloProject>>lastVersion'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '1/21/2011 09:33'.
		spec 
			project: 'Gofer Core' with: '1.0.2.2';
			project: 'Gofer Tests' with: '1.0.2.2'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.457';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.505';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.24';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.80';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.139';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.29';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-DaleHenrichs.87'. ].

	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.19'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-DaleHenrichs.9'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.5'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.24'. ].

	spec for: #'pharo1.2.x' do: [
		spec 
			project: 'OB' with: '1.2.3';
			project: 'ProfStef' with: '1.6'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta282: spec
	<version: '1.0-beta.28.2' imports: #('1.0-beta.28-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- add #''pharo1.3.x'' attribute
- get rid of #sortBy: ... deprecated in Pharo1.2 '.
		spec author: 'DaleHenrichs'.
		spec timestamp: '1/23/2011 10:46'.
		spec 
			project: 'Gofer Core' with: '1.0.2.2';
			project: 'Gofer Tests' with: '1.0.2.2'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.458';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.505';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.24';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.80';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.139';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.29';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-DaleHenrichs.87'. ].

	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.19'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-DaleHenrichs.9'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.5'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.25'. ].

	spec for: #'pharo1.2.x' do: [
		spec 
			project: 'OB' with: '1.2.3';
			project: 'ProfStef' with: '1.6'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta28311: spec
	<version: '1.0-beta.28.3.1.1' imports: #('1.0-beta.28.3.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.0-beta.28.3.1.1 (dkh.603):
- cherry pick the clean up repository code from Metacello-TestsMC-dkh.146
- tests green in Squeak4.2alpha update #10892
  376 run, 375 passes, 1 expected failures, 0 failures, 0 errors, 0 unexpected passes
1.0-beta.28.3.1.1 (dkh.604):
- clean up a few more repositories ...'.
		spec author: 'dkh'.
		spec timestamp: '4/18/2011 18:40'.
		spec 
			project: 'Gofer Core' with: '1.0.5';
			project: 'Gofer Tests' with: '1.0.5'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.460';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.507';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.24';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.81';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.148';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.30';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-DaleHenrichs.88'. ].

	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.20'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-DaleHenrichs.9'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.5'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.25'. ].

	spec for: #'pharo1.2.x' do: [
		spec 
			project: 'OB' with: '1.2.3';
			project: 'ProfStef' with: '1.6'.
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.1'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta2831: spec
	<version: '1.0-beta.28.3.1' imports: #('1.0-beta.28.3.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- fix Issue 3758: Metacello has 12 failing tests in 1.2
  http://code.google.com/p/pharo/issues/detail?id=3758
- well ... add expectedFails for the tests are failing due to the fix for Pharo Issue 3660'.
		spec author: 'dkh'.
		spec timestamp: '2/25/2011 19:42'.
		spec 
			project: 'Gofer Core' with: '1.0.2.2';
			project: 'Gofer Tests' with: '1.0.2.2'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.460';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.507';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.24';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.81';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.140';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.29';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-DaleHenrichs.88'. ].

	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.20'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-DaleHenrichs.9'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.5'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.25'. ].

	spec for: #'pharo1.2.x' do: [
		spec 
			project: 'OB' with: '1.2.3';
			project: 'ProfStef' with: '1.6'.
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.1'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta2832: spec
	<version: '1.0-beta.28.3.2' imports: #('1.0-beta.28.3.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '- fix a problem with a "naked" project: call in a version method ... run into this error during automated generation
- fix Issue 123: broken development scenario
  http://code.google.com/p/metacello/issues/detail?id=123
- fix Issue 120:lessons methods disapppeared in Metacello-Tutorial-DaleHenrichs.24
  http://code.google.com/p/metacello/issues/detail?id=120
- proposed fix for Issue 122: misleading error message regarding stable versions
  http://code.google.com/p/metacello/issues/detail?id=122
- parrallel current version calculations...(actually found real-life case where parallel is better)
- minor toolbox tweak ... commitMethod should be okay with no methodSpec ... just noop
- fix Issue 118: dirty package after merge skews currentVersion calculation
  http://code.google.com/p/metacello/issues/detail?id=118
- MetacelloCurrentVersionTest>>testIssue118 added to validate the fix'.
		spec author: 'dkh'.
		spec timestamp: '3/20/2011 19:52'.
		spec 
			project: 'Gofer Core' with: '1.0.2.2';
			project: 'Gofer Tests' with: '1.0.2.2'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.463';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.510';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.25';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.81';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.143';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.29';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.95'. ].

	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.20'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-DaleHenrichs.9'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.5'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.25'. ].

	spec for: #'pharo1.2.x' do: [
		spec 
			project: 'OB' with: '1.2.3';
			project: 'ProfStef' with: '1.6'.
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.1'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta2833: spec
	<version: '1.0-beta.28.3.3' imports: #('1.0-beta.28.3.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- fix Issue 4049: Failing Tests 1.3 Full: MetaCello
  http://code.google.com/p/pharo/issues/detail?id=4049'.
		spec author: 'dkh'.
		spec timestamp: '4/27/2011 02:50'.
		spec 
			project: 'Gofer Core' with: '1.0.2.2';
			project: 'Gofer Tests' with: '1.0.2.2'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.460';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.507';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.24';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.81';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.140';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.29';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-DaleHenrichs.88'. ].

	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.20'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-DaleHenrichs.9'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.5'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.25'. ].

	spec for: #'pharo1.2.x' do: [
		spec 
			project: 'OB' with: '1.2.3';
			project: 'ProfStef' with: '1.6'.
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.1'. ].

	spec for: #'pharo1.3.x' do: [
		spec 
			project: 'OB' with: '1.3';
			project: 'ProfStef' with: '1.7'.
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.1'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta283: spec
	<version: '1.0-beta.28.3' imports: #('1.0-beta.28-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- fix errors in MetacelloVersionValidator class>>populateReasonCodeDescriptions and MetacelloMCVersionValidator class>>populateReasonCodeDescriptions
- #sort: needs to be used instead of #sorted: for GemStone3.0 compatability
- after sorting reconvert Arrays to OrderedCollections
- when saving packages and configuration, dump diffs to Transcript
- fix a spot where refresh of package is needed while calculating current version (when in #development)
- add #maglev attribute for conditional maglev code [GemStone]'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '02/02/2011 17:07:53'.
		spec 
			project: 'Gofer Core' with: '1.0.2.2';
			project: 'Gofer Tests' with: '1.0.2.2'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.460';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.507';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.24';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.81';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.140';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.29';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-DaleHenrichs.88'. ].

	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.20'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-DaleHenrichs.9'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.5'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.25'. ].

	spec for: #'pharo1.2.x' do: [
		spec 
			project: 'OB' with: '1.2.3';
			project: 'ProfStef' with: '1.6'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta284: spec
	<version: '1.0-beta.28.4' imports: #('1.0-beta.28-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '- open 1.0-beta.28.4 for development
- improve MetacelloToolBox class>>stripVersionStringForSelector: algorithm
- fix Issue 108:	Need to update Metacello (tests and Gofer config) to integrate changes from Pharo Issue 3660
  http://code.google.com/p/metacello/issues/detail?id=108
- add MetacelloToolBox class>>stableVersion:for:platformAttribute: for MetacelloBrowser
- warn about newer versions when saving modified packages
- check for possibly newer versions when saving configuration
- testing (so there''s a halt in here too)

- warning is better than a halt ... any day
pick up patch for Pharo  Issue 3763: assert failure during Decompiler>>popIntoTemporaryVariable:
  http://code.google.com/p/pharo/issues/detail?id=3763

- integrate the parallel currentVersion calculation ... no ill affectcts yet
- another sent but not implemented cleanup for GemStone
- fix a problem with a "naked" project: call in a version method ... run into this error during automated generation
- proposed fix for Issue 122: misleading error message regarding stable versions
  http://code.google.com/p/metacello/issues/detail?id=122
- parrallel current version calculations...(actually found real-life case where parallel is better)'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '3/18/2011 15:47'.
		spec 
			project: 'Gofer Core' with: '1.0.2.2';
			project: 'Gofer Tests' with: '1.0.2.2'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.463';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.509';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.24';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.81';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.142';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.30';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.94'. ].

	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.20'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-DaleHenrichs.9'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.5'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.25'. ].

	spec for: #'pharo1.2.x' do: [
		spec 
			project: 'OB' with: '1.2.3';
			project: 'ProfStef' with: '1.6'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta285: spec
	<version: '1.0-beta.28.5' imports: #('1.0-beta.28.3.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'copy from 1.0-beta.28.3.1.1 ... 1.0-beta.28.5 is a better name:)
1.0-beta.28.3.1.1 (dkh.603):
- cherry pick the clean up repository code from Metacello-TestsMC-dkh.146
- tests green in Squeak4.2alpha update #10892
  376 run, 375 passes, 1 expected failures, 0 failures, 0 errors, 0 unexpected passes
1.0-beta.28.3.1.1 (dkh.604):
- clean up a few more repositories ...'.
		spec author: 'dkh'.
		spec timestamp: '4/18/2011 18:40'.
		spec 
			project: 'Gofer Core' with: '1.0.5';
			project: 'Gofer Tests' with: '1.0.5'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.461';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.507';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.24';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.81';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.148';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.30';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-DaleHenrichs.88'. ].

	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.20'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-DaleHenrichs.9'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.5'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.25'. ].

	spec for: #'pharo1.2.x' do: [
		spec 
			project: 'OB' with: '1.2.3';
			project: 'ProfStef' with: '1.6'.
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.1'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta28: spec
	<version: '1.0-beta.28' imports: #('1.0-beta.28-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- pick up #versionKey from work done with Simon during ESUG 2010
- add MetacelloPlatform>>primeStackCacheWith:doing: from work done with Simon during ESUG 2010
- deprecate MetacelloPlatform>>primeStackCacheFor:doing:defaultDictionary:
- add primeStackCache tests
- dynamic caching for 5x speedup of #currentVersion
- standard Pharo version attributes: #''pharo1.x'', #''pharo1.0.x'', #''pharo1.1.x'', #''pharo1.2.x''
- throw an error when a version is not found
- collapse running zeroes in a version number in absence of a numeric element
- introduce MetacelloBaseConfiguration added so that Configurations can have a superclass (not yet ready for use)
- introduce symbolic versions. 
  - #development, #stable, and #bleedingEdge are standard versions.
  - a default is defined for #bleedingEdge
- fix Issue 100: http://code.google.com/p/metacello/issues/detail?id=100 "last block wins when there are duplicate attribute blocks"
- added two new commands for OB-Metacello: ''Validate Configuration'' and ''ValidateConfiguration Version''
- MetacelloToolBox added
- transferred tutorial lessons to ProfStef
- convert OB-Metacello to use MetacelloToolbox API
- update comments for api documentation
- help browser documentation loaded as part of default group (for Pharo....for now)
- speed up running of tests ... 3x faster
- postLoad and preLoad doit behavior cleaned up with regards to overriding behaviour using nil arg (i.e.,  stop preload/postload doits)
- add Squeak attributes: #''squeak3.10.x'', #''squeak4.1.x'', and #''squeak4.2.x''
- fix pharo bug 3516: http://code.google.com/p/pharo/issues/detail?id=3516 "Failing tests in MetaCello"
- OB-Metacello commands functional in Pharo1.2'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '1/17/2011 10:12'.
		spec 
			project: 'Gofer Core' with: '1.0.2.2';
			project: 'Gofer Tests' with: '1.0.2.2'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.455';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.505';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.24';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.80';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.138';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.29';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-DaleHenrichs.87'. ].

	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.19'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-DaleHenrichs.9'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.5'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.24'. ].

	spec for: #'pharo1.2.x' do: [
		spec 
			project: 'OB' with: '1.2.3';
			project: 'ProfStef' with: '1.6'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta28ea0: spec
	<version: '1.0-beta.28-ea.0' imports: #('1.0-beta.28-ea-baseline' )>

	spec for: #common do: [
		spec blessing: #development.
		spec description: '- snap off an early access version so folks can play with symbolic versions, etc. while I continue development
- pick up #versionKey from work done with Simon during ESUG 2010
- add MetacelloPlatform>>primeStackCacheWith:doing: from work done with Simon during ESUG 2010
- deprecate MetacelloPlatform>>primeStackCacheFor:doing:defaultDictionary:
- add primeStackCache tests
- dynamic caching for 5x speedup of #currentVersion
- standard Pharo version attributes: #''pharo1.x'', #''pharo1.0.x'', #''pharo1.1.x'', #''pharo1.2.x''
- throw an error when a version is not found
- collapse running zeroes in a version number in absence of a numeric element
- integrated changes from 1.0-beta.27.5
- introduce MetacelloBaseConfiguration added so that Configurations can have a superclass (or not)
- introduce symbolic versions. 
  - #development, #stable, and #bleedingEdge are standard versions.
  - a default is defined for each of them in the abstract configuration
- if versionString not defined for project reference, #bleedingEdge version is used as the default (instead of latest version)
- stop using #lastMetacelloVersionLoad altogether
- add Configuration validation 
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '11/4/2010 12:35'.
		spec 
			project: 'Gofer Core' with: '1.0.2.1';
			project: 'Gofer Tests' with: '1.0.2.1'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.3';
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.379';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.438';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.23';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.60';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.16';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.12';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.116';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.10'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-tbn.3'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.17'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta28ea1: spec
	<version: '1.0-beta.28-ea.1' imports: #('1.0-beta.28-ea-baseline' )>

	spec for: #common do: [
		spec blessing: #development.
		spec description: '- clean up undefined symbols refs in Metacello-Base
- adjust validation to provide warning when no version is specified 
- differentiate between versions not specified, but resolved and versions not resolved in validation
- validation for duplicate attribute blocks
- fix Issue 100: http://code.google.com/p/metacello/issues/detail?id=100 "last block wins when there are duplicate attribute blocks"
- add symbolic versions to version chooser in OB-Metacello
- recursive validation option
- extended validation to restrict recursive validation of a particular version 
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '11/5/2010 11:13'.
		spec 
			project: 'Gofer Core' with: '1.0.2.1';
			project: 'Gofer Tests' with: '1.0.2.1'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.4';
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.385';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.439';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.23';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.62';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.16';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.12';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.118';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.10'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-tbn.3'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.17'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta28ea2: spec
	<version: '1.0-beta.28-ea.2' imports: #('1.0-beta.28-ea-baseline' )>

	spec for: #common do: [
		spec blessing: #development.
		spec description: '- only bleedingEdge has a standard default ... most other versions like #stable and #development should have a static version specidifed instead of a dynamic version
- pragma for default version methods i.e., <defaultSymbolicVersion: #bleedingEdge>
- symbolic versions (Including default) are resolved during project construction, so all version information is in the spec
- changed labels in OB-Metacello to use ''Configuration'' instead of ''Project'', renamed classes to reflect this change
- added two new commands for OB-Metacello: ''Validate Configuration'' and ''ValidateConfiguration Version''
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '11/8/2010 11:22'.
		spec 
			project: 'Gofer Core' with: '1.0.2.1';
			project: 'Gofer Tests' with: '1.0.2.1'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.5';
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.388';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.442';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.23';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.63';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.16';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.12';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.118';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.10'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-tbn.3'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.17'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta28ea3: spec
	<version: '1.0-beta.28-ea.3' imports: #('1.0-beta.28-ea.3-baseline' )>

	spec for: #common do: [
		spec blessing: #development.
		spec description: '- add MetacelloMCVersion>>difference: for getting differences between two versions ... primarily listing added/removed/modified mcz files and project version strings.
- add loop detection to validation
- stop using deprecated in Pharo1.2 methods (sortBy:)
- Metacello Tool box
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '11/12/2010 17:00'.
		spec 
			project: 'Gofer Core' with: '1.0.2.1';
			project: 'Gofer Tests' with: '1.0.2.1'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.5';
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.398';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.453';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.23';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.65';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.16';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.118';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.10';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-DaleHenrichs.6'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-tbn.3'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.17'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta28ea4: spec
	<version: '1.0-beta.28-ea.4' imports: #('1.0-beta.28-ea.3-baseline' )>

	spec for: #common do: [
		spec blessing: #development.
		spec description: '- additional validation conditions
- more tool box work
- update ProfStef tutorial to include MetacelloToolBox examples
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '11/14/2010 15:35'.
		spec 
			project: 'Gofer Core' with: '1.0.2.1';
			project: 'Gofer Tests' with: '1.0.2.1'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.5';
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.401';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.455';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.23';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.66';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.16';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.118';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.10';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-DaleHenrichs.11'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-tbn.3'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.3';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.17'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta28ea5: spec
	<version: '1.0-beta.28-ea.5' imports: #('1.0-beta.28-ea.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '- transferred tutorial lessons to ProfStef
- convert OB-Metacello to use MetacelloToolbox API
- validate configuration before saving
- portable copyClass for toolbox
- use #notDefined when a symbolicVersion is not defined ... that way you can define a symbolic version for #common and "undefine" the symbolic version for #pharo
- allow a symbolicVersion to reference another symbolic version ... do loop detection etc...improved
- add auto-generated Metacello method and class based Help Browser entries
- add ability to exclude validation issues (moral equivalent of expected failure in SUnit)
- fine tune recommended development process
- update comments for api documentation
- help browser documentation loaded as part of default group (for Pharo....for now)'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '12/1/2010 12:35'.
		spec 
			project: 'Gofer Core' with: '1.0.3';
			project: 'Gofer Tests' with: '1.0.3'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.7';
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.429';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.480';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.24';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.78';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.16';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.118';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.16';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-DaleHenrichs.59'.].

	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.18'.].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: '1.2.1';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-DaleHenrichs.4'.].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.5'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.7';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.22'.].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.7'.].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta29: spec
	<version: '1.0-beta.29' imports: #('1.0-beta.29-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- fix a problem with a "naked" project: call in a version method ... run into this error during automated generation
- fix Issue 123: broken development scenario
  http://code.google.com/p/metacello/issues/detail?id=123
- fix Issue 120:lessons methods disapppeared in Metacello-Tutorial-DaleHenrichs.24
  http://code.google.com/p/metacello/issues/detail?id=120
- proposed fix for Issue 122: misleading error message regarding stable versions
  http://code.google.com/p/metacello/issues/detail?id=122
- parrallel current version calculations...(actually found real-life case where parallel is better)
- minor toolbox tweak ... commitMethod should be okay with no methodSpec ... just noop
- fix Issue 118: dirty package after merge skews currentVersion calculation
  http://code.google.com/p/metacello/issues/detail?id=118
- MetacelloCurrentVersionTest>>testIssue118 added to validate the fix
- OPEN 1.0-beta.29 FOR DEVELOPMENT ***************** following from 1.0-beta.28.4 merge
- improve MetacelloToolBox class>>stripVersionStringForSelector: algorithm
- fix Issue 108:	Need to update Metacello (tests and Gofer config) to integrate changes from Pharo Issue 3660
  http://code.google.com/p/metacello/issues/detail?id=108
- add MetacelloToolBox class>>stableVersion:for:platformAttribute: for MetacelloBrowser
- warn about newer versions when saving modified packages
- check for possibly newer versions when saving configuration
- testing (so there''s a halt in here too)
- warning is better than a halt ... any day
pick up patch for Pharo  Issue 3763: assert failure during Decompiler>>popIntoTemporaryVariable:
  http://code.google.com/p/pharo/issues/detail?id=3763
- integrate the parallel currentVersion calculation ... no ill affectcts yet
- another sent but not implemented cleanup for GemStone
- fix a problem with a "naked" project: call in a version method ... run into this error during automated generation
- proposed fix for Issue 122: misleading error message regarding stable versions
  http://code.google.com/p/metacello/issues/detail?id=122
- parrallel current version calculations...(actually found real-life case where parallel is better)
***************** preceding from 1.0-beta.28.4 merge
- open 1.0-beta.29 for development
- merge 1.0-beta.28.3.2 and 1.0-beta.28.4 development threads
- turns out that MetacelloBrowser needs the new development stuff anyway & MetacelloBrowser can live in a development image anyway 
- MetacelloIssue115TestCase currently in limbo

- tests for Issue 115
- getting started on a caching scheme for goferReferences for use during the fetch phase ...
- SIGNIFICANT speedup for fetch:
  - cache repository contents for duration of fetch cycle
  - use packageCache (when available) for loading version info
1.0-beta.29 (dkh.582):
- cache only network-based repositories in MetacelloGofer
- clear cacheGofer when setting cacheRepository for MetacelloLoaderPolicy
1.0-beta.29 (dkh.583):
- clear ensuredMap when setting cacheRepository for MetacelloLoaderPolicy
1.0-beta.29 (dkh.584):
- add in support for branching configurations (mcz level branch)
1.0-beta.29 (dkh.585):
- help system loaded by default in Squeak, too
- add configuration help support
1.0-beta.29 (dkh.588):
- config help should allow for inclusion of a class (like custom help)
- include MetacelloHelp (if installed) in ConfigurationOfMetacello help..
1.0-beta.29 (dkh.590):
- in case HelpSystem not installed ...
1.0-beta.29 (dkh.591):
- better logic for default installation help
1.0-beta.29 (dkh.592):
- another tweak to logic: #stable version, class-side load, latest version load
- fix a bug
1.0-beta.29 (dkh.594):
- support for update projects command in MetacelloBrowser
1.0-beta.29 (dkh.595):
- restore a method to avoid upgrade issues
tweak
1.0-beta.29 (dkh.598):
- fixed a bug in MetacelloToolBox class>>saveModifiedDevelopmentPackages:for:description:

1.0-beta.29 ():
- implement GoferVersionReference>>metacelloPackageNameWithBranch ... improve branching support
1.0-beta.29 (dkh.600):
- add support for _creating_ configuration branches
1.0-beta.29 (dkh.601):
- use Gofer 1.0.5 (integerate Pharo branch changes into Squeak and GemStone versions)
- clean up repositories left in default MCRepositoryGroup ...
1.0-beta.29 (dkh.606):
- merge changes from 1.0-beta.28.5
1.0-beta.29 (dkh.607):
- remove expectedFailures ... 
1.0-beta.29 (dkh.608):
- 379 run, 379 passes, 0 expected failures, 0 failures, 0 errors, 0 unexpected passes
- tests finalized for issues 108, 115, and 118
1.0-beta.29 (dkh.611):
- empty package Metacello-Issue3758, so that expectedFailures aren''t left intact
1.0-beta.29 (dkh.612):
- better information in transcript on retry
1.0-beta.29 (dkh.612):
- add MetacelloToolBox class>>currentlyLoadedExtensionClassesInVersion in support of Naviode
1.0-beta.29 (dkh.615):
- fix Issue 112: direct version load (upgrade) of config doesn''t update already loaded mcz files
  http://code.google.com/p/metacello/issues/detail?id=112

1.0-beta.29 (dkh.619):
- defaultTimeout to be compatible with Squeak test cases'.
		spec author: 'dkh'.
		spec timestamp: '6/7/2011 16:02'.
		spec 
			project: 'Gofer Core' with: '1.0.5';
			project: 'Gofer Tests' with: '1.0.5'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.465';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.522';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.25';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.81';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.153';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.31';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.105'. ].

	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.20'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: #'stable';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-dkh.11'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: #'stable'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.25'. ].

	spec for: #'pharo1.2.x' do: [
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'. ].

	spec for: #'pharo1.3.x' do: [
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta2: spec
	<version: '1.0-beta.2' imports: #('1.0-beta.0-baseline')>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Bugfixes:
- change name of method used for bootstrapping to avoid confusion with methods actually used for loading.
- port to Squeak (Squeak3..10.10.2-Trunk-090912)'.
		spec author: 'dkh'.
		spec timestamp: '10/12/2009 13:31'.
		spec 
			package: 'Gofer' with: 'Gofer-dkh.65';
			package: 'Metacello-Core' with: [
				spec
					file: 'Metacello-Core-dkh.268';
					includes: #('Metacello-Reference' ) ];
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.197';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.12';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.25';
			package: 'Metacello-ConfigTests' with: 'Metacello-ConfigTests-dkh.7';
			package: 'Metacello-ReferenceTests' with: 'Metacello-ReferenceTests-dkh.1'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta30: spec
	<version: '1.0-beta.30' imports: #('1.0-beta.30-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '1.0-beta.30 (dkh.621):
- another round of performance improvements with significant speedups for #currentVersion, #project,  #versionStatus and friends
1.0-beta.30 (dkh.622):
- minor tweaks for performance enhancements
- tweak MetacelloToolBox class>>saveModifiedPackagesAndConfigurationIn:description: so that description is updated when you package updates are needed.
1.0-beta.30 (dkh.623):
- persistent author initials can be set by defining #''GS_tODE_AuthorInitials'' in UserGlobals with desired author initials string (in support of tODE) [GemStone only]
1.0-beta.30 (dkh.624):
- allow configuration branches to be used in a project reference (className: is name sans branch, file: is name with branch)
1.0-beta.30 (dkh.625):
- fix validation when branched configuration is used
1.0-beta.30 (dkh.626):
- fix Issue 136: load of referenced project can fail with missing version error
  http://code.google.com/p/metacello/issues/detail?id=136
1.0-beta.30 (dkh.627):
- fix Issue 146:unrecognized SystemVersion results in assuming system is on #gemstone...
  http://code.google.com/p/metacello/issues/detail?id=146
- tests pass in Pharo1.4, though ProfStef apparently has not been ported (yet)'.
		spec author: 'dkh'.
		spec timestamp: '9/9/2011 15:48'.
		spec 
			project: 'Gofer Core' with: '1.0.5';
			project: 'Gofer Tests' with: '1.0.5'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.467';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.527';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.25';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.81';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.155';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.32';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-DataCurator.106'. ].

	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.237.2'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.21'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: #'stable';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-dkh.11'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: #'stable'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.27'. ].

	spec for: #'pharo1.2.x' do: [
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'. ].

	spec for: #'pharo1.3.x' do: [
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'SeanDeNigris 6/18/2012 20:59'!
version10beta3113: spec
	<version: '1.0-beta.31.1.3' imports: #('1.0-beta.31.1.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '1.0-beta.31.1.3 (spd.695);
- add LatAm squeaksource mirror for dependent projects'.
		spec author: 'spd'.
		spec timestamp: '06/18/2012 20:57'.
		spec 
			project: 'Gofer Core' with: '1.0.5.1';
			project: 'Gofer Tests' with: '1.0.5.1'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.468';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.531';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.25';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.82';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.158';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.32';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.107'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'OB' with: #'stable';
			project: 'Monticello' with: '0.242'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-dkh.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.23'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: #'stable';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-dkh.11'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: #'stable'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.27'. ].

	spec for: #'pharo1.2.x' do: [
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'. ].

	spec for: #'pharo1.3.x' do: [
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'SeanDeNigris 6/27/2012 22:16'!
version10beta3114: spec
	<version: '1.0-beta.31.1.4' imports: #('1.0-beta.31.1.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '1.0-beta.31.1.4;
- split Platform.pharo package for 2.0'.
		spec author: 'spd'.
		spec timestamp: '06/27/2012 22:10'.
		spec 
			project: 'Gofer Core' with: '1.0.5.1';
			project: 'Gofer Tests' with: '1.0.5.1'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.468';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.531';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.25';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.82';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.158';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.32';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.107'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'OB' with: #'stable';
			project: 'Monticello' with: '0.242'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-dkh.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.23'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: #'stable';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-dkh.11'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: #'stable'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.27'. ].

	spec for: #'pharo1.2.x' do: [
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'. ].

	spec for: #'pharo1.3.x' do: [
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'. ].
	
	spec for: #'pharo2.x' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo20-SeanDeNigris.28'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 9/16/2012 18:09'!
version10beta3115: spec
    <version: '1.0-beta.31.1.5' imports: #('1.0-beta.31.1.5-baseline')>
    spec
        for: #'common'
        do: [ 
            spec blessing: #'release'.
            spec
                description:
                    '1.0-beta.31.1.5;
- fis Issue 73 - update Metacello-MC to a version which adds custom project attribute support to MetacelloConfigTemplate
  https://github.com/dalehenrich/metacello-work/issues/73
- fix Issue 114 - get all of the unit tests passing
  https://github.com/dalehenrich/metacello-work/issues/114
- fix Issue 120 - nested `version:imports:` cause trouble (1.0-beta.31.1.5)
  https://github.com/dalehenrich/metacello-work/issues/120
- fix Issue 110 - allow attribute lists in #for:do: statement
  https://github.com/dalehenrich/metacello-work/issues/110
- fix Issue 69 - MetacelloConfigurationTutorial undefined reference to ToolSet
  https://github.com/dalehenrich/metacello-work/issues/69
- fix Issue 115 - Version generated from a baseline can have empty package versions in a platform-specific section
  https://github.com/dalehenrich/metacello-work/issues/115
- support for Issue 129 - deployment scripts
  https://github.com/dalehenrich/metacello-work/issues/129'.
            spec author: 'dkh'.
            spec timestamp: '9/14/2012 16:49'.
            spec
                project: 'Gofer Core' with: '1.0.5.1';
                project: 'Gofer Tests' with: '1.0.5.1'.
            spec
                package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
                package: 'Metacello-Core' with: 'Metacello-Core-dkh.492';
                package: 'Metacello-MC' with: 'Metacello-MC-dkh.664';
                package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
                package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.25';
                package: 'OB-Metacello' with: 'OB-Metacello-dkh.82';
                package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
                package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
                package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.351';
                package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.33';
                package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.130' ].
    spec
        for: #'gemstone'
        do: [ 
            spec
                project: 'OB' with: #'stable';
                project: 'Monticello' with: '0.242'.
            spec
                package: 'Metacello-MC' with: [ spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt' ];
                package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-dkh.2';
                package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.23' ].
    spec
        for: #'squeakCommon'
        do: [ 
            spec
                project: 'OB' with: #'stable';
                project: 'Help System' with: '1.1'.
            spec
                package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
                package: 'Metacello-Help' with: 'Metacello-Help-dkh.11' ].
    spec
        for: #'pharo'
        do: [ 
            spec project: 'ProfStef' with: #'stable'.
            spec
                package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-dkh.13';
                package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-dkh.5';
                package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.27' ].
    spec for: #'pharo1.0.x' do: [ spec package: 'Metacello-ProfStef' with: 'Metacello-ProfStef.toolset-dkh.12' ].
    spec for: #'pharo1.1.x' do: [ spec package: 'Metacello-ProfStef' with: 'Metacello-ProfStef.toolset-dkh.12' ].
    spec
        for: #'pharo1.2.x'
        do: [ 
            spec
                package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2';
                package: 'Metacello-ProfStef' with: 'Metacello-ProfStef.toolset-dkh.12' ].
    spec for: #'pharo1.3.x' do: [ spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2' ].
    spec for: #'pharo2.x' do: [ spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo20-SeanDeNigris.28' ].
    spec for: #'squeak' do: [ spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.14' ]! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 3/21/2013 15:54'!
version10beta3116: spec
    <version: '1.0-beta.31.1.6' imports: #('1.0-beta.31.1.5-baseline')>
    spec
        for: #'common'
        do: [ 
            spec blessing: #'release'.
            spec
                description:
                    '1.0-beta.31.1.6 (dkh.753);
- fix Issue 141 - squeak4.3.x and squeak4.4.x added as platform attributes
  https://github.com/dalehenrich/metacello-work/issues/141'.
            spec author: 'dkh'.
            spec timestamp: '3/21/2013 14:10'.
            spec
                project: 'Gofer Core' with: '1.0.5.1';
                project: 'Gofer Tests' with: '1.0.5.1'.
            spec
                package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
                package: 'Metacello-Core' with: 'Metacello-Core-dkh.492';
                package: 'Metacello-MC' with: 'Metacello-MC-dkh.664';
                package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
                package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.25';
                package: 'OB-Metacello' with: 'OB-Metacello-dkh.82';
                package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
                package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
                package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.351';
                package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.33';
                package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.130' ].
    spec
        for: #'gemstone'
        do: [ 
            spec
                project: 'OB' with: #'stable';
                project: 'Monticello' with: '0.242'.
            spec
                package: 'Metacello-MC' with: [ spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt' ];
                package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-dkh.2';
                package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.23' ].
    spec
        for: #'squeakCommon'
        do: [ 
            spec
                project: 'OB' with: #'stable';
                project: 'Help System' with: '1.1'.
            spec
                package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
                package: 'Metacello-Help' with: 'Metacello-Help-dkh.11' ].
    spec
        for: #'pharo'
        do: [ 
            spec project: 'ProfStef' with: #'stable'.
            spec
                package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-dkh.13';
                package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-dkh.5';
                package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.27' ].
    spec for: #'pharo1.0.x' do: [ spec package: 'Metacello-ProfStef' with: 'Metacello-ProfStef.toolset-dkh.12' ].
    spec for: #'pharo1.1.x' do: [ spec package: 'Metacello-ProfStef' with: 'Metacello-ProfStef.toolset-dkh.12' ].
    spec
        for: #'pharo1.2.x'
        do: [ 
            spec
                package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2';
                package: 'Metacello-ProfStef' with: 'Metacello-ProfStef.toolset-dkh.12' ].
    spec for: #'pharo1.3.x' do: [ spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2' ].
    spec for: #'pharo2.x' do: [ spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo20-SeanDeNigris.28' ].
    spec for: #'squeak' do: [ spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.17' ]! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 06/29/2013 08:23'!
version10beta3117: spec
  <version: '1.0-beta.31.1.7' imports: #('1.0-beta.31.1.7-baseline')>
  spec
    for: #'common'
    do: [ 
      spec blessing: #'release'.
      spec description: '1.0-beta.31.1.7 (dkh.774):
- fix Issue #172: Metacello-Base bootstrap code and configurations should reference seaside.gemtalksystems.com repos
  https://github.com/dalehenrich/metacello-work/issues/172'.
      spec author: 'dkh'.
      spec timestamp: '6/29/2013 08:23'.
      spec
        project: 'Gofer Core' with: '1.0.5.1';
        project: 'Gofer Tests' with: '1.0.5.1'.
      spec
        package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
        package: 'Metacello-Core' with: 'Metacello-Core-dkh.492';
        package: 'Metacello-MC' with: 'Metacello-MC-dkh.664';
        package: 'Metacello-Reference'
          with: 'Metacello-Reference-DaleHenrichs.31';
        package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.25';
        package: 'OB-Metacello' with: 'OB-Metacello-dkh.82';
        package: 'Metacello-TestsReference'
          with: 'Metacello-TestsReference-DaleHenrichs.17';
        package: 'Metacello-TestsCore'
          with: 'Metacello-TestsCore-DaleHenrichs.14';
        package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.351';
        package: 'Metacello-TestsTutorial'
          with: 'Metacello-TestsTutorial-dkh.33';
        package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.130' ].
  spec
    for: #'gemstone'
    do: [ 
      spec
        project: 'OB' with: #'stable';
        project: 'Monticello' with: '0.242'.
      spec
        package: 'Metacello-MC'
          with: [ spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt' ];
        package: 'Metacello-TestsPlatform'
          with: 'Metacello-TestsPlatform.gemstone-dkh.2';
        package: 'Metacello-Platform'
          with: 'Metacello-Platform.gemstone-dkh.23' ].
  spec
    for: #'squeakCommon'
    do: [ 
      spec
        project: 'OB' with: #'stable';
        project: 'Help System' with: '1.1'.
      spec
        package: 'Metacello-TestsPlatform'
          with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
        package: 'Metacello-Help' with: 'Metacello-Help-dkh.11' ].
  spec
    for: #'pharo'
    do: [ 
      spec project: 'ProfStef' with: #'stable'.
      spec
        package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-dkh.13';
        package: 'Metacello-TestsProfStef'
          with: 'Metacello-TestsProfStef-dkh.5';
        package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.27' ].
  spec
    for: #'pharo1.0.x'
    do: [ spec package: 'Metacello-ProfStef' with: 'Metacello-ProfStef.toolset-dkh.12' ].
  spec
    for: #'pharo1.1.x'
    do: [ spec package: 'Metacello-ProfStef' with: 'Metacello-ProfStef.toolset-dkh.12' ].
  spec
    for: #'pharo1.2.x'
    do: [ 
      spec
        package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2';
        package: 'Metacello-ProfStef' with: 'Metacello-ProfStef.toolset-dkh.12' ].
  spec
    for: #'pharo1.3.x'
    do: [ spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2' ].
  spec
    for: #'pharo2.x'
    do: [ 
      spec
        package: 'Metacello-Platform'
        with: 'Metacello-Platform.pharo20-SeanDeNigris.28' ].
  spec
    for: #'squeak'
    do: [ spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.17' ]! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 7/23/2013 16:31'!
version10beta3118: spec
  <version: '1.0-beta.31.1.8' imports: #('1.0-beta.31.1.7-baseline')>
  spec
    for: #'common'
    do: [ 
      spec blessing: #'release'.
      spec description: '1.0-beta.31.1.8 (dkh.789):
- fix Issue #188: Problems using <version:imports:> for structural reasons
  https://github.com/dalehenrich/metacello-work/issues/188'.
      spec author: 'dkh'.
      spec timestamp: '7/23/2013 09:48'.
      spec
        project: 'Gofer Core' with: '1.0.5.1';
        project: 'Gofer Tests' with: '1.0.5.1'.
      spec
        package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
        package: 'Metacello-Core' with: 'Metacello-Core-dkh.494';
        package: 'Metacello-MC' with: 'Metacello-MC-dkh.664';
        package: 'Metacello-Reference'
          with: 'Metacello-Reference-DaleHenrichs.31';
        package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.25';
        package: 'OB-Metacello' with: 'OB-Metacello-dkh.82';
        package: 'Metacello-TestsReference'
          with: 'Metacello-TestsReference-DaleHenrichs.17';
        package: 'Metacello-TestsCore'
          with: 'Metacello-TestsCore-DaleHenrichs.14';
        package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.353';
        package: 'Metacello-TestsTutorial'
          with: 'Metacello-TestsTutorial-dkh.33';
        package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.130' ].
  spec
    for: #'gemstone'
    do: [ 
      spec
        project: 'OB' with: #'stable';
        project: 'Monticello' with: '0.242'.
      spec
        package: 'Metacello-MC'
          with: [ spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt' ];
        package: 'Metacello-TestsPlatform'
          with: 'Metacello-TestsPlatform.gemstone-dkh.2';
        package: 'Metacello-Platform'
          with: 'Metacello-Platform.gemstone-dkh.23' ].
  spec
    for: #'squeakCommon'
    do: [ 
      spec
        project: 'OB' with: #'stable';
        project: 'Help System' with: '1.1'.
      spec
        package: 'Metacello-TestsPlatform'
          with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
        package: 'Metacello-Help' with: 'Metacello-Help-dkh.11' ].
  spec
    for: #'pharo'
    do: [ 
      spec project: 'ProfStef' with: #'stable'.
      spec
        package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-dkh.13';
        package: 'Metacello-TestsProfStef'
          with: 'Metacello-TestsProfStef-dkh.5';
        package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.27' ].
  spec
    for: #'pharo1.0.x'
    do: [ spec package: 'Metacello-ProfStef' with: 'Metacello-ProfStef.toolset-dkh.12' ].
  spec
    for: #'pharo1.1.x'
    do: [ spec package: 'Metacello-ProfStef' with: 'Metacello-ProfStef.toolset-dkh.12' ].
  spec
    for: #'pharo1.2.x'
    do: [ 
      spec
        package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2';
        package: 'Metacello-ProfStef' with: 'Metacello-ProfStef.toolset-dkh.12' ].
  spec
    for: #'pharo1.3.x'
    do: [ spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2' ].
  spec
    for: #'pharo2.x'
    do: [ 
      spec
        package: 'Metacello-Platform'
        with: 'Metacello-Platform.pharo20-SeanDeNigris.28' ].
  spec
    for: #'squeak'
    do: [ spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.17' ]! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta311: spec
	<version: '1.0-beta.31.1' imports: #('1.0-beta.31.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '1.0-beta.31.1 (dkh.642);
- open 1.0-beta.31.1 for development
- GemStone/S 2.4.5 support
- missing OB dependency for GemStone
1.0-beta.31.1 (dkh.643);
- GsMonticello 0.242
1.0-beta.31.1 (dkh.644);
- trigger #gemstone10beta311PostLoadDoIt
1.0-beta.31.1 (dkh.645);
- fix Issue 155: Notification for skipped config loads
  http://code.google.com/p/metacello/issues/detail?id=155
1.0-beta.31.1 (dkh.646):
- help fix GemStone Issue 307: http://code.google.com/p/glassdb/issues/detail?id=307
1.0-beta.31.1 (dkh.647):
- log when loading over modified package ... part of Issue 155'.
		spec author: 'dkh'.
		spec timestamp: '11/17/2011 13:33'.
		spec 
			project: 'Gofer Core' with: '1.0.5.1';
			project: 'Gofer Tests' with: '1.0.5.1'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.468';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.531';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.25';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.82';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.158';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.32';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.107'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'OB' with: #'stable';
			project: 'Monticello' with: '0.242'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-dkh.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.23'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: #'stable';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-dkh.11'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: #'stable'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.27'. ].

	spec for: #'pharo1.2.x' do: [
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'. ].

	spec for: #'pharo1.3.x' do: [
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta312: spec
	<version: '1.0-beta.31.2' imports: #('1.0-beta.31.1-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #development.
			spec
				description:
					'1.0-beta.31.2 (dkh.649):
- fix Issue 163: MetacellMCProjectSpec>>ensureProjectLoaded doesn''t honor cacheRepository: or overrideRepository:
  http://code.google.com/p/metacello/issues/detail?id=163
1.0-beta.31.2 (dkh.650):
- clean up logging for Issue 163
1.0-beta.31.2 (dkh.651):
- more logging clean up
1.0-beta.31.2 (dkh.652):
- during ensured configuration loads, need to clear more of the cache.
1.0-beta.31.2 (dkh.653):
- when loading a new version of a config, ALL references to the project need to be nuked.
1.0-beta.31.2 (dkh.654):
- cached packages should only be loaded during an ensureLoad.
1.0-beta.31.2 (dkh.655):
- fix Issue 150: #stable version shouldn''t cause upgrade from project reference
  http://code.google.com/p/metacello/issues/detail?id=150'.
			spec author: 'dkh'.
			spec timestamp: '1/3/2012 11:15'.
			spec
				project: 'Gofer Core' with: '1.0.5.1';
				project: 'Gofer Tests' with: '1.0.5.1'.
			spec
				package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
				package: 'Metacello-Core' with: 'Metacello-Core-dkh.468';
				package: 'Metacello-MC' with: 'Metacello-MC-dkh.538';
				package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
				package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.25';
				package: 'OB-Metacello' with: 'OB-Metacello-dkh.82';
				package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
				package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
				package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.161';
				package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.32';
				package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.107' ].
	spec
		for: #gemstone
		do: [ 
			spec
				project: 'OB' with: #stable;
				project: 'Monticello' with: '0.242'.
			spec
				package: 'Metacello-MC' with: [ spec preLoadDoIt: #gemstone10beta24PreLoadDoIt ];
				package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-dkh.2';
				package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.23' ].
	spec
		for: #squeakCommon
		do: [ 
			spec
				project: 'OB' with: #stable;
				project: 'Help System' with: '1.1'.
			spec
				package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
				package: 'Metacello-Help' with: 'Metacello-Help-dkh.11' ].
	spec
		for: #pharo
		do: [ 
			spec project: 'ProfStef' with: #stable.
			spec
				package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
				package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
				package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.27' ].
	spec for: #'pharo1.2.x' do: [ spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2' ].
	spec for: #'pharo1.3.x' do: [ spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2' ].
	spec for: #squeak do: [ spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10' ]! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta31: spec
	<version: '1.0-beta.31' imports: #('1.0-beta.31-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '1.0-beta.31 (dkh.633);
- clean up port to GemStone
1.0-beta.31 (dkh.635):
- fix for GemStone version of Pharo Issue 4613 .... derive attributes from GemStone version string
- get Monticello configuration from correct repository
1.0-beta.31 (dkh.636):
- use Gofer 1.0.5.1 (for GemStone)
1.0-beta.31 (dkh.637):
- changing the comparison logic for Monticello branches. It used to be that branched Monticello packages had a funky sort order based on lenght of the branch, etc ... total malarkey really. For Metacello when a branched package is compared to a non-branched package that just just fail the comparisons and there is no "latest" relationship in either direction ... this has the effect of forcing an override of non-branched by branched and vice versa. Also if two versions differ in author name only, they compare equal ... no good can come of that situation no matter how you cut it.  Considering that I believe that GemStone is the only place where branched Monticello packages are regularly used in a configuration, I feel pretty confident that if I make GemStone happy everyone else will be happy as well.
1.0-beta.31 (dkh.638):
- previous checkin was too aggressive ... there needs to be a consistent package ordering scheme or else seesaw loading will ensue
- version number is the primary sorting key when package names are the same ... branch then author is used only when version numbers are the same '.
		spec author: 'dkh'.
		spec timestamp: '10/20/2011 14:33'.
		spec 
			project: 'Gofer Core' with: '1.0.5.1';
			project: 'Gofer Tests' with: '1.0.5.1'.
		spec 
			package: 'Metacello-Base' with: 'Metacello-Base-DaleHenrichs.19';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.467';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.529';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.25';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.81';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.17';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.14';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.157';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.32';
			package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.107'. ].

	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.237.2'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt'. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-dkh.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.22'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'OB' with: #'stable';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-dkh.11'. ].

	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: #'stable'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.10';
			package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.27'. ].

	spec for: #'pharo1.2.x' do: [
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'. ].

	spec for: #'pharo1.3.x' do: [
		spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'. ].

	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.10'. ].
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'topa 1/28/2015 00:43'!
version10beta321: spec
  <version: '1.0-beta.32.1' imports: #('1.0-beta.32.1-baseline')>
  spec
    for: #'common'
    do: [ 
      spec blessing: #'development'.
      spec
        description:
          '- add squeak4.5.x as platform attribute
- minor hack to get Metacello Preview to bootstrap (again) on Squeak4.4 and Squeak4.5
1.0-beta.32.1 (dkh.758):
- Issue #65: port to Pharo-2.0
  https://github.com/dalehenrich/metacello-work/issues/65
1.0-beta.32.1 (dkh.762):
- adjust dependencies for tests
- fix tests when loaded from mcz files
1.0-beta.32.1 (dkh.764):
- switch to using http://smalltalkhub.com/mc/dkh/metacello/main as alternate repository to http://seaside.gemstone.com/ss/metacello
- fix Issue #151: travis builds hanging for Squeak-4.4 and Squeak4.5
  https://github.com/dalehenrich/metacello-work/issues/151
1.0-beta.32.1 (dkh.765):
- workaround for SmalltalkHub Issue 21: corrupted package .... Metacello-Reference.dkh.35
  https://code.google.com/p/smalltalk-hub/issues/detail?id=21
1.0-beta.32.1 (dkh.767):
- workaround for SmalltalkHub Issue 21: corrupted package .... Metacello-TestsPlatform.squeakCommon-dkh.9
- bootstrap from Metacello-Base needs to load Metacello-PharoCommonPlatform
1.0-beta.32.1 (dkh.774):
- fix Issue #172: Metacello-Base bootstrap code and configurations should reference seaside.gemtalksystems.com repos
  https://github.com/dalehenrich/metacello-work/issues/172
1.0-beta.32.1 (dkh.780):
- pick up latest package versions from git repo ... preparing for release
1.0-beta.32.1 (dkh.781):
- fix Issue #170: location of ConfigurationOfOsProcess for Pharo2.0+ changed
  https://github.com/dalehenrich/metacello-work/issues/170
1.0-beta.32.1 (dkh.782):
- split tests into two groups to avoid travis-ci 30 minute limit
- fix google Issue 184: github zip download failures due to filesystem issues
  https://code.google.com/p/metacello/issues/detail?id=184
- fix Issue #175: MCGitHubRepository and cache
  https://github.com/dalehenrich/metacello-work/issues/175
- fix Issue #174: `lock` should work with symbolic versions
  https://github.com/dalehenrich/metacello-work/issues/174
- fix Issue #176: attempt to modify immutable project spec
  https://github.com/dalehenrich/metacello-work/issues/176
- fix Issue #181: The case for `unconditional` baseline loading
  https://github.com/dalehenrich/metacello-work/issues/181
1.0-beta.32.1 (dkh.782):
- final fix for Issue #187: avoid OSProcess dependency for Pharo3.0
  https://github.com/dalehenrich/metacello-work/issues/181
1.0-beta.32.1 (dkh.797):
- Issue #281: backport PR #257
1.0-beta.32.1 (dkh.798):
- Issue #281: backport Issue #227
1.0-beta.32.1 (dkh.799):
- Issue #281: backport Issue #226 fix.
- Pick up current WebClient for Squeak, to actually be able to use Metacello on Mac with SqueakSSL'.
			spec postLoadDoIt: #metacelloPrimeRegistry.
			spec author: 'topa'.
			spec timestamp: '1/28/2015 00:42' "printIt: [MetacelloPlatform current timestamp]".
			spec project: 'FileTree' with: #stable;
				 project: 'Gofer' with: #stable;
				 project: 'Gofer Tests' with: #stable.
			spec package: 'Metacello-Base' with: 'Metacello-Base-dkh.109';
				 package: 'Metacello-Core' with: 'Metacello-Core-dkh.695';
				 package: 'Metacello-FileTree' with: 'Metacello-FileTree-dkh.29';
				 package: 'Metacello-GitHub' with: 'Metacello-GitHub-dkh.29';
				 package: 'Metacello-MC' with: 'Metacello-MC-dkh.680';
				 package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.36';
				 package: 'Metacello-TestsCommonMC' with: 'Metacello-TestsCommonMC.common-dkh.3';
				 package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.35';
				 package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.387';
				 package: 'Metacello-TestsMCA' with: 'Metacello-TestsMCA-dkh.7';
				 package: 'Metacello-TestsMCB' with: 'Metacello-TestsMCB-dkh.13';
				 package: 'Metacello-TestsMCCore' with: 'Metacello-TestsMCCore-dkh.5';
				 package: 'Metacello-TestsMCResources' with: 'Metacello-TestsMCResources-dkh.4';
				 package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.20';
				 package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-ChristopheDemarey.41';
				 package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.134';
				 package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.26'].
	spec
		for: #squeakCommon
		do: [spec project: 'HelpSystem' with: '1.1'.
			spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.11';
				 package: 'Metacello-Help' with: 'Metacello-Help-dkh.12'].
	spec
		for: #pharo
		do: [spec project: 'ProfStef' with: #stable;
				 project: 'OSProcess' with: #stable.
			spec package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-dkh.13';
				 package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-ChristopheDemarey.5';
				 package: 'Metacello-PharoCommonPlatform' with: 'Metacello-PharoCommonPlatform-dkh.3'].
	spec
		for: #'pharo1.x'
		do: [spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.34'].
	spec
		for: #'pharo1.2.x'
		do: [spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'].
	spec
		for: #'pharo1.3.x'
		do: [spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'].
	spec
		for: #'pharo2.x'
		do: [spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo20-dkh.40';
				 package: 'Metacello-TestsCommonMC' with: 'Metacello-TestsCommonMC.pharo20-dkh.3'].
	spec
		for: #'pharo3.x'
		do: [spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo30-ChristopheDemarey.3';
				 package: 'Metacello-TestsCommonMC' with: 'Metacello-TestsCommonMC.pharo20-dkh.3'].
	spec
		for: #squeak
		do: [spec project: 'WebClient' with: #stable;
				 package: 'SqueakSSL-Core' with: 'SqueakSSL-Core-ar.26';
				 package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-tfel.25'].
	spec
		for: #gemstone
		do: [spec project: 'GsCore' with: '0.247';
				 project: 'GsMonticello' with: '0.244.2'.
			spec
				package: 'Metacello-MC'
				with: [spec preLoadDoIt: #gemstone10beta24PreLoadDoIt];
				 package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-.6';
				 package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.33']
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'tfel 7/29/2014 14:43'!
version10beta322: spec
  <version: '1.0-beta.32.2' imports: #('1.0-beta.32.2-baseline')>
  spec
    for: #'common'
    do: [ 
      spec blessing: #'development'.
      spec
        description:
          '- switch from using curl/unzip to WebClient and ZipArchive on Squeak'.
      spec postLoadDoIt: #'metacelloPrimeRegistry'.
      spec author: 'tfel'.
      spec timestamp: '29/7/2014 14:02'.
      spec
        project: 'FileTree' with: #'stable';
        project: 'Gofer' with: #'stable';
        project: 'Gofer Tests' with: #'stable'.
      spec
        package: 'Metacello-Base' with: 'Metacello-Base-dkh.109';
        package: 'Metacello-Core' with: 'Metacello-Core-dkh.694';
        package: 'Metacello-FileTree' with: 'Metacello-FileTree-dkh.29';
        package: 'Metacello-GitHub' with: 'Metacello-GitHub-dkh.29';
        package: 'Metacello-MC' with: 'Metacello-MC-dkh.680';
        package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.36';
        package: 'Metacello-TestsCommonMC'
          with: 'Metacello-TestsCommonMC.common-dkh.3';
        package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.35';
        package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.387';
        package: 'Metacello-TestsMCA' with: 'Metacello-TestsMCA-dkh.7';
        package: 'Metacello-TestsMCB' with: 'Metacello-TestsMCB-dkh.13';
        package: 'Metacello-TestsMCCore' with: 'Metacello-TestsMCCore-dkh.5';
        package: 'Metacello-TestsMCResources'
          with: 'Metacello-TestsMCResources-dkh.4';
        package: 'Metacello-TestsReference'
          with: 'Metacello-TestsReference-dkh.20';
        package: 'Metacello-TestsTutorial'
          with: 'Metacello-TestsTutorial-ChristopheDemarey.41';
        package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.134';
        package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.26' ].
  spec
    for: #'squeakCommon'
    do: [ 
      spec
        project: 'OSProcess' with: '4.4.5';
        project: 'HelpSystem' with: '1.1'.
      spec
        package: 'Metacello-TestsPlatform'
          with: 'Metacello-TestsPlatform.squeakCommon-dkh.11';
        package: 'Metacello-Help' with: 'Metacello-Help-dkh.12' ].
  spec
    for: #'pharo'
    do: [ 
      spec
        project: 'ProfStef' with: #'stable';
        project: 'OSProcess' with: #'stable'.
      spec
        package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-dkh.13';
        package: 'Metacello-TestsProfStef'
          with: 'Metacello-TestsProfStef-ChristopheDemarey.5';
        package: 'Metacello-PharoCommonPlatform'
          with: 'Metacello-PharoCommonPlatform-dkh.3' ].
  spec
    for: #'pharo1.x'
    do: [ spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.34' ].
  spec
    for: #'pharo1.2.x'
    do: [ spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2' ].
  spec
    for: #'pharo1.3.x'
    do: [ spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2' ].
  spec
    for: #'pharo2.x'
    do: [ 
      spec
        package: 'Metacello-Platform' with: 'Metacello-Platform.pharo20-dkh.40';
        package: 'Metacello-TestsCommonMC'
          with: 'Metacello-TestsCommonMC.pharo20-dkh.3' ].
  spec
    for: #'pharo3.x'
    do: [ 
      spec
        package: 'Metacello-Platform'
          with: 'Metacello-Platform.pharo30-ChristopheDemarey.3';
        package: 'Metacello-TestsCommonMC'
          with: 'Metacello-TestsCommonMC.pharo20-dkh.3' ].
  spec
    for: #'squeak'
    do: [ spec
             package: 'Metacello-Platform'
               with: 'Metacello-Platform.squeak-tfel.25';
             package: 'SqueakSSL-Core'
               with: 'SqueakSSL-Core-ar.26';
             package: 'WebClient-Core'
               with: 'WebClient-Core-topa.93'. ].
  spec
    for: #'gemstone'
    do: [ 
      spec
        project: 'GsCore' with: '0.247';
        project: 'GsMonticello' with: '0.244.2'.
      spec
        package: 'Metacello-MC'
          with: [ spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt' ];
        package: 'Metacello-TestsPlatform'
          with: 'Metacello-TestsPlatform.gemstone-.6';
        package: 'Metacello-Platform'
          with: 'Metacello-Platform.gemstone-dkh.32' ]! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'topa 9/14/2017 14:23'!
version10beta323: spec
  <version: '1.0-beta.32.3' imports: #('1.0-beta.32.3-baseline')>
  spec
    for: #'common'
    do: [ 
      spec blessing: #'development'.
      spec
        description:
          '- Avoid loading WebClient/SqueakSSL with older Versions in Squeak images that already have support'.
			spec postLoadDoIt: #metacelloPrimeRegistry.
			spec author: 'topa'.
			spec timestamp: '1/28/2015 00:42' "printIt: [MetacelloPlatform current timestamp]".
			spec project: 'FileTree' with: #stable;
				 project: 'Gofer' with: #stable;
				 project: 'Gofer Tests' with: #stable.
			spec package: 'Metacello-Base' with: 'Metacello-Base-dkh.109';
				 package: 'Metacello-Core' with: 'Metacello-Core-dkh.695';
				 package: 'Metacello-FileTree' with: 'Metacello-FileTree-dkh.29';
				 package: 'Metacello-GitHub' with: 'Metacello-GitHub-dkh.29';
				 package: 'Metacello-MC' with: 'Metacello-MC-dkh.680';
				 package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.36';
				 package: 'Metacello-TestsCommonMC' with: 'Metacello-TestsCommonMC.common-dkh.3';
				 package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.35';
				 package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.387';
				 package: 'Metacello-TestsMCA' with: 'Metacello-TestsMCA-dkh.7';
				 package: 'Metacello-TestsMCB' with: 'Metacello-TestsMCB-dkh.13';
				 package: 'Metacello-TestsMCCore' with: 'Metacello-TestsMCCore-dkh.5';
				 package: 'Metacello-TestsMCResources' with: 'Metacello-TestsMCResources-dkh.4';
				 package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.20';
				 package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-ChristopheDemarey.41';
				 package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.134';
				 package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.26'].
	spec
		for: #squeakCommon
		do: [spec project: 'HelpSystem' with: '1.1'.
			spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.11';
				 package: 'Metacello-Help' with: 'Metacello-Help-dkh.12'].
	spec
		for: #pharo
		do: [spec project: 'ProfStef' with: #stable;
				 project: 'OSProcess' with: #stable.
			spec package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-dkh.13';
				 package: 'Metacello-TestsProfStef' with: 'Metacello-TestsProfStef-ChristopheDemarey.5';
				 package: 'Metacello-PharoCommonPlatform' with: 'Metacello-PharoCommonPlatform-dkh.3'].
	spec
		for: #'pharo1.x'
		do: [spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.34'].
	spec
		for: #'pharo1.2.x'
		do: [spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'].
	spec
		for: #'pharo1.3.x'
		do: [spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2'].
	spec
		for: #'pharo2.x'
		do: [spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo20-dkh.40';
				 package: 'Metacello-TestsCommonMC' with: 'Metacello-TestsCommonMC.pharo20-dkh.3'].
	spec
		for: #'pharo3.x'
		do: [spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo30-ChristopheDemarey.3';
				 package: 'Metacello-TestsCommonMC' with: 'Metacello-TestsCommonMC.pharo20-dkh.3'].
	spec
		for: #'squeak'
		do: [spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-tfel.25'].
	spec
		for: #( #'squeak4.1.x' #'squeak4.2.x' #'squeak4.3.x' #'squeak4.4.x' #'squeak4.5.x' )
		do: [spec project: 'WebClient' with: #stable;
				 package: 'SqueakSSL-Core' with: 'SqueakSSL-Core-ar.26'].
	spec
		for: #gemstone
		do: [spec project: 'GsCore' with: '0.247';
				 project: 'GsMonticello' with: '0.244.2'.
			spec
				package: 'Metacello-MC'
				with: [spec preLoadDoIt: #gemstone10beta24PreLoadDoIt];
				 package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-.6';
				 package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.33']
! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 12/18/2013 14:59'!
version10beta32: spec
  <version: '1.0-beta.32' imports: #('1.0-beta.32-baseline')>
  spec
    for: #'common'
    do: [ 
      spec blessing: #'development'.
      spec
        description:
          'equivalent to 6fb14916d605429808f10bb2bc90be8f320beb42
snap off a release for GLASS 1.0-beta.9
- unimplemented message being sent in MetacelloProjectSpec>>asProjectRegistration
  https://github.com/dalehenrich/metacello-work/issues/139
- squeak4.3.x and squeak4.4.x added as platform attributes
  https://github.com/dalehenrich/metacello-work/issues/140
- add squeak4.5.x as platform attribute
- minor hack to get Metacello Preview to bootstrap (again) on Squeak4.4 and Squeak4.5'.
      spec author: 'dkh'.
      spec timestamp: '5/5/2013 14:46'.
      spec postLoadDoIt: #'metacelloPrimeRegistryFor10beta32'.
      spec
        project: 'FileTree' with: '1.0.1';
        project: 'Gofer' with: '1.0.5.1';
        project: 'Gofer Tests' with: '1.0.5.1'.
      spec
        package: 'Metacello-Base' with: 'Metacello-Base-dkh.103';
        package: 'Metacello-Core' with: 'Metacello-Core-dkh.669';
        package: 'Metacello-FileTree' with: 'Metacello-FileTree-dkh.29';
        package: 'Metacello-GitHub' with: 'Metacello-GitHub-dkh.22';
        package: 'Metacello-MC' with: 'Metacello-MC-dkh.669';
        package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.35';
        package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.26';
        package: 'OB-Metacello' with: 'OB-Metacello-dkh.83';
        package: 'Metacello-TestsReference'
          with: 'Metacello-TestsReference-dkh.20';
        package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.31';
        package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.352';
        package: 'Metacello-TestsTutorial'
          with: 'Metacello-TestsTutorial-dkh.40';
        package: 'Metacello-ToolBox' with: 'Metacello-ToolBox-dkh.131' ].
  spec
    for: #'squeakCommon'
    do: [ 
      spec
        project: 'OSProcess' with: '4.4.5';
        project: 'OmniBrowser' with: #'stable';
        project: 'HelpSystem' with: '1.1'.
      spec
        package: 'Metacello-TestsPlatform'
          with: 'Metacello-TestsPlatform.squeakCommon-dkh.8';
        package: 'Metacello-Help' with: 'Metacello-Help-dkh.12' ].
  spec
    for: #'pharo'
    do: [ 
      spec project: 'ProfStef' with: #'stable'.
      spec
        package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-dkh.13';
        package: 'Metacello-TestsProfStef'
          with: 'Metacello-TestsProfStef-dkh.4';
        package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.30' ].
  spec
    for: #'pharo1.2.x'
    do: [ spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2' ].
  spec
    for: #'pharo1.3.x'
    do: [ spec package: 'Metacello-Issue3758' with: 'Metacello-Issue3758-dkh.2' ].
  spec
    for: #'pharo2.x'
    do: [ spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo20-dkh.30' ].
  spec
    for: #'squeak'
    do: [ spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.21' ].
  spec
    for: #'gemstone'
    do: [ 
      spec
        project: 'OmniBrowser' with: #'stable';
        project: 'GsCore' with: '0.247';
        project: 'GsMonticello' with: '0.244.2'.
      spec
        package: 'Metacello-MC'
          with: [ spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt' ];
        package: 'Metacello-TestsPlatform'
          with: 'Metacello-TestsPlatform.gemstone-dkh.4';
        package: 'Metacello-Platform'
          with: 'Metacello-Platform.gemstone-dkh.29' ]! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta3: spec
	<excludedValidationIssues: #('1.0-beta.3' #(noVersionSpecified))>
	<version: '1.0-beta.3' imports: #('1.0-beta.3-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Bugfixes:
- update to latest Gofer (Gofer-lr.67)
- fix a package overrides: bug
- pull in some old tests that still apply
- recast tutorial to new API plus tutorial tests
- fix platform attribute bug
- use strings instead of symbols for imports
- class-side project
- fix doit bug
- tools load ''ALL''
- deactive ''Update Repositories'' command'.
		spec author: 'dkh'.
		spec timestamp: '10/14/2009 10:06'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.67';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.271';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.201';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.13';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.12';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.27';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.1';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.2';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.1'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta4: spec
	<excludedValidationIssues: #('1.0-beta.4' #(noVersionSpecified))>
	<version: '1.0-beta.4' imports: #('1.0-beta.3-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Bugfixes:
- add platform attribute tests
- fix bug in project reference
- need to pass project into constructor (sometimes)
- duplication of #projectAttributes
- correct update package logic when package branches involved (<package name>.<branch name>-<author>.<version number>'.
		spec author: 'dkh'.
		spec timestamp: '10/15/2009 11:41'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.67';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.273';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.205';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.13';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.12';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.27';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.1';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.4';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.1'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta5: spec
	<excludedValidationIssues: #('1.0-beta.5' #(noVersionSpecified))>
	<version: '1.0-beta.5' imports: #('1.0-beta.5-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- GemStone port
- fix a bug in #project:copyFrom:with:
- rewrite null loader to use IVs for recording state
- get started on project ref tutorial
- ensure that imported versions exist
- use Gofer for direct loading of packages like from pojects, since configuration must be loaded immediately whether or not w are doing atomic/linear loads
- add project load test (coverage for Doru''s bug report)'.
		spec author: 'dkh'.
		spec timestamp: '10/18/2009 10:41'.
		spec 
			package: 'Gofer' with: 'Gofer-dkh.68';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.276';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.208';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.15';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.13';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.27';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.2';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.7';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.2'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.5'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta6: spec
	<excludedValidationIssues: #('1.0-beta.6' #(noVersionSpecified))>
	<version: '1.0-beta.6' imports: #('1.0-beta.5' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Bugfixes:
- asNumber throws Error (as of 10487) and Errors are not resumable
- bump up ensureMetacello methods to use versions from 1.0-beta.6
- use latest version of Gofer'.
		spec author: 'dkh'.
		spec timestamp: '10/19/2009 10:50'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.70';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.277';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.209';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.14'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta7: spec
	<excludedValidationIssues: #('1.0-beta.7' #(noVersionSpecified))>
	<version: '1.0-beta.7' imports: #('1.0-beta.5-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- finish project ref tutorial'.
		spec author: 'dkh'.
		spec timestamp: '10/19/2009 13:50'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.70';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.277';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.209';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.15';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.15';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.27';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.2';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.7';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.3'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.5'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta8: spec
	<excludedValidationIssues: #('1.0-beta.8' #(noVersionSpecified))>
	<version: '1.0-beta.8' imports: #('1.0-beta.5-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- protect senders of asNumber with error handler'.
		spec author: 'dkh'.
		spec timestamp: '10/20/2009 11:30'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.70';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.277';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.210';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.15';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.15';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.27';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.2';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.7';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.3'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.5'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta9: spec
	<excludedValidationIssues: #('1.0-beta.9' #(noVersionSpecified))>
	<version: '1.0-beta.9' imports: #('1.0-beta.5-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- second cut at package query api for MetacellMCVersion requested by Simon, Read the method comments for documentation:
	- groups
	- packages
	- projects
	- packagesForSpecNamed:
	- allPackagesForSpecNamed:
- add #repository:username:password: to configuration API in support of repositories that require authentication.'.
		spec author: 'dkh'.
		spec timestamp: '10/22/2009 10:38'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.70';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.279';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.215';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.16';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.15';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.27';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.3';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.10';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.3'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.5'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !
